****************************************************************   
* Program name:  assign_p2.sas                                    
* Author:        Steve Ross                                        
* Final Version: Oct 4, 2002
* Project:       Housing Discrimination Study Phase 2
*                                                                  
* This program assign_p2.sas reads the raw data from the Tester   
* Assignment Form (TAF) that is stored in the sas data set entitled
* assignme.ssd01 for the phase2 data.  Records are merged by control 
* number in order to create a single record for the paired assignment 
* associated with each test.  
*                                                                  
* Input Files:  assignme.ssd01                                       
*                                                                  
* Output Files:  assignp2.ssd01                                     
*                                                                  
****************************************************************;  

options nocenter ;

/* ref lib */
libname hds2000 '/work/ross' ;

/* ref files */
filename assignme '/work/ross/assignme.ssd01' ;
filename taf '/work/ross/taf.ssd01' ;

filename assignp2 '/work/ross/assignp2.ssd01' ;

/* delete invalid tests */

data taf ; set hds2000.taf ;
keep control fpass ;
proc sort ; by control ;

data assign ; set hds2000.assignme ;
proc sort ; by control ;

data assign ;
  merge assign (in=q1) taf(in=q2) ;
  by control ;
  if q1 and q2 ;

data assign ; set assign ;
  if fpass=1 then output assign ;
  else delete ;

data assign ; set assign ;
   nsite=substr(control,1,2) ;
   ntype=substr(control,4,1) ;
   ngroup=substr(control,5,1) ;
   triad=0 ;
   if ngroup='5' then do ;
     triad=1 ;
     ngroup='1' ;
     end ;
   if ngroup='6' then do ;
     triad=1 ;
     ngroup='2' ;
     end ;

   if raceid<20 then race=raceid-10 ;
     else if raceid>30 then race=raceid-30 ;
     else race=raceid-20 ;
   
   if raceid>30 then delete ;
     else output assign ;

data assign ; set assign ;
  if atsttype=1 then ahometyp=phmtypr ;
  if atsttype=2 then ahometyp=phmtyps ;


/* save information for white assignement */

data wassign ;
  set assign ;
  wtestrid=testerid ;
  wtestnm=tname ;
  wrace=arace1 ;
  wage=aage1 ;
  wsex=tsex ;
  wincome=aincmont ;
  wincom2=aincyrt ;
  wmarried=0 ;
  if arelate2=2 or arelate3=2 or arelate4=2 or arelate5=2 then wmarried=1 ;
  wchild=0 ;
  if arelate2=3 or arelate3=3 or arelate4=3 or arelate5=3 then wchild=1 ;
  wtotasst=atotasst ;
  wcrdbal=acrdbalt ;
  wcrdpay=acrdmont ;
  wrent=arentnow ;
  wlength=algncur ;
  wbedreq=pbeds ;
  wbedmin=pminbed ;
  whometyp=ahometyp ;
  wsitenam=ppname ;
  wsitestr=paddrs ;
  wsitecit=pcity ;
  wsitesta=pstate ;
  wtype=atsttype ;
  waprice=aprir ;  /* price range var, char ?? */
  wneed=phneed ; /* a rental only variable */
  wdate=addate ;
  wweek=week ;
  wtestid=testerid ;

  keep control nsite ntype ngroup
  wtype wtestrid wrace wage wsex wincome wmarried 
  wchild wtotasst wcrdbal wcrdpay wrent wlength wbedreq wbedmin 
  whometyp wtestnm wsitenam wsitestr wsitecit wsitesta waprice 
  wdate wneed wweek wincom2 raceid wtestid ;

  if race=1 then output wassign ;
    else delete ;


proc sort ; by control ;

/* save information for minority assignment */

data massign ;
  set assign ;
  mtestrid=testerid ;
  mtestnm=tname ;
  mrace=arace1 ;
  mage=aage1 ;
  msex=tsex ;
  mincome=aincmont ;
  mincom2=aincyrt ;
  mmarried=0 ;
  if arelate2=2 or arelate3=2 or arelate4=2 or arelate5=2 then mmarried=1 ;
  mchild=0 ;
  if arelate2=3 or arelate3=3 or arelate4=3 or arelate5=3 then mchild=1 ;
  mtotasst=atotasst ;
  mcrdbal=acrdbalt ;
  mcrdpay=acrdmont ;
  mrent=arentnow ;
  mlength=algncur ;
  mbedreq=pbeds ;
  mbedmin=pminbed ;
  mhometyp=ahometyp ;
  msitenam=ppname ;
  msitestr=paddrs ;
  msitecit=pcity ;
  msitesta=pstate ;
  mtype=atsttype ;
  maprice=aprir ;  /* price range var, char ?? */
  mneed=phneed ; /* a rental only variable */
  mdate=addate ;
  mweek=week ; 
  mtestid=testerid ;

  keep control nsite ntype ngroup
  mtype mtestrid mrace mage msex mincome mmarried 
  mchild mtotasst mcrdbal mcrdpay mrent mlength mbedreq mbedmin 
  mhometyp mtestnm msitenam msitestr msitecit msitesta maprice 
  mdate mneed mweek mincom2 raceid mtestid ;

  if race^=1 then output massign ;
    else delete ;


proc sort ; by control ;

data hds2000.assignp2 ;
merge wassign (in=q1) massign (in=q2) ;
by control ; 
if q1 and q2 ;

proc freq ;
  tables ntype*nsite*ngroup ;
		
proc contents ;


run;
	















