****************************************************************     
* Program name:  rental_merge_p2.sas                                     
* Project:       Housing Discrimination Study Phase II                
*                                                                    
*  Final version: Nov 27, 2002 by Steve Ross                     
*                                                                    
*  This program merges together the final sample of sales tests      
*  with counts and means from the sample of rental units recommended 
*  or inspected by the testers, as well as information on whether    
*  follow-up contact was made by the real estate agent.  The         
*  resulting sample is used along with phase I data to create  
*  phase II results                                            
*                                                                    
* Input Files:   assignp2.ssd01, rentalp2.ssd01, followp2.ssd01, unitsp2.ssd01
*                                                                    
* Output Files:  mrgrp2.ssd01                                      
*                                                                    
****************************************************************;    




options nocenter ;

libname hds2000 '/work/ross' ;

/* ref file */
filename rentalp2 '/work/ross/rentalp2.ssd01' ;
filename assignp2 '/work/ross/assignp2.ssd01' ;
filename followp2 '/work/ross/followp2.ssd01' ;
filename unitsp2 '/work/ross/unitsp2.ssd01' ;
filename tester '/work/ross/tester.ssd01' ;
filename ph2skint '/work/ross/ph2skint.ssd01' ;

/* new file to be created */
filename mrgrp2 '/work/ross/mrgrp2.ssd01' ;

/*---------------------loading ref files----------------------------*/



/* load test final sample */

data tests ; set hds2000.rentalp2 ;
data follow ; set hds2000.followp2 ;
data assign ; set hds2000.assignp2 ;
data unit ; set hds2000.unitsp2 ;
data ph2skint ; set hds2000.ph2skint ;
  mtestid=testerid ;
  keep mtestid ranking ;
proc sort ; by mtestid ;
proc means ;
  var ranking ;
    by mtestid ;
  output out=skintone mean=mrank ;
  

data tester ;  set hds2000.tester ;
  mtestid=testerid ;
  maccent=taccent ;
  masiang=tasiang ;
  keep mtestid maccent masiang ;
proc sort ; by mtestid ;

/* load sample with information on followup contacts */

data follow ; set follow ;
  if totcnt2>0 then follow=1 ;
  else follow=0 ;
  if race=1 then white=1 ;
    else white=0 ;
  keep control white follow ;

proc sort ; by control white ;


data unit ; set unit ;

  count=1 ;

  if race=1 then white=1 ;
    else white=0 ;

/* available when I need it */

                                                                
  if ruavlbl3<adate_y or adate_y=. or ruavlbl3=. then timeav=1 ;
    else  if ruavlbl3>adate_y then timeav=0 ;                   
    else if ruavlbl1<adate_m                                    
       or adate_m=. or ruavlbl1=. then timeav=1 ;               
    else if ruavlbl1>adate_m then timeav=0 ;                    
    else if ruavlbl2<=adate_d or adate_d=. or ruavlbl2=.        
        then timeav=1 ;                                         
    else timeav=0 ;                                             

/*  size and price range */  
  
  if abedreql<=rubed<=abedrequ or rubed=. or abedreql=. then meetbreq=1 ;
    else if rubed in (0.5, 1.5, 2.5, 3.5, 4.5, 5.5) then do ;
       if abedreql<=rubed-0.5<=abedrequ or abedreql<=rubed+0.5<=abedrequ  
           then meetbreq=1 ;
       else meetbreq=0 ;
       end ;
     else meetbreq=0 ;
  if rubed+0.5>=abedmin then meetbmin=1 ;
    else if meetbreq=1 then meetbmin=1 ;
    else meetbmin=0 ;

                                                              
 if rurent<=apricehl or rurent=. or apricehl=. then meetprng=1 ;
   else meetprng=0 ;                                          
                                                              
 if rurent<=apricehl or rurent=. or apricehl=. then meetprn2=1 ;          
   else meetprn2=0 ;                                          
                                                                
  /* advertised unit and inspection */

  if ruinad=1 then advunit=1 ;
    else advunit=0 ;
  if ruinsp=1 then inspect=1 ;
    else inspect=0 ;
  if inspect=1 and advunit=1 then inspadv=1 ;
    else inspadv=0 ;
  if advunit=1 and meetbreq=1 
     then advmeet=1 ; else advmeet=0 ;
  if advunit=1 and meetbreq=1 
     then advmeet2=1 ; else advmeet2=0 ;
  if advunit=1 and meetbmin=1 
     and advmeet=0 then advacc=1 ; else advacc=0 ;
  if advunit=1 and meetbmin=1 
     and advmeet2=0 then advacc2=1 ; else advacc2=0 ;

  /* similar unit and inspection */

  if meetbreq=1 and advunit=0 then similar=1 ;
    else similar=0 ;
  if inspect=1 and similar=1 then inspsim=1 ;
    else inspsim=0 ;
  if meetbreq=1 and advunit=0 then similar2=1 ;
    else similar2=0 ;
  if inspect=1 and similar2=1 then inspsim2=1 ;
    else inspsim2=0 ;
  if ruspcl=1 and advunit=1 then advspcl=1 ;
    else advspcl=0 ;

  /* acceptable unit and inspection */

  if meetbmin=1 and advunit=0 and similar=0 then accept=1 ;
    else accept=0 ;
  if inspect=1 and accept=1 then inspacc=1 ;
    else inspacc=0 ;
  if meetbmin=1 and advunit=0 and similar2=0 then accept2=1 ;
    else accept2=0 ;
  if inspect=1 and accept2=1 then inspacc2=1 ;
    else inspacc2=0 ;
  if ruspcl=1 and similar=1 then simspcl=1 ;
    else simspcl=0 ;

  /* application fee and incentives */

  if rutotfee>0 and rutotfee^=. then rutotfee=1 ;
    else rutotfee=0 ;
  if ruspcl=. or (ruspcl^=1 and ruspcl^=0) then ruspcl=0 ;

 /* calculate rent, security deposit, and amenities for advertised units 
 as well as whether specific utilities are provided */                   

                                     
  if advunit=1 then do ;             
     advrent=rurent ;               
     advsec=rudepsts ;
     end ;
  if similar=1 then do ;      
     simrent=rurent ;        
     simsec=rudepsts ;        
     end ;

/* create units level variables */

  proc sort data=unit ;
    by control white ;

/* create variables on numbers of units by visit */

proc means noprint data=unit ;
  by control white ;
  var count inspect advunit inspadv advmeet advmeet2 advacc advacc2
      similar similar2 inspsim inspsim2 accept accept2 inspacc inspacc2 
      advspcl simspcl rutotfee ruspcl ;
  output out=sumunit sum=number numinsp numadv advinsp advmtm advmtm2
      advaccm advaccm2 numsim numsim2 siminsp siminsp2 numacc numacc2
      accinsp accinsp2 nadvspcl nsimspcl rfeereq rspcl;

/* create variables on number of advertised units in test */

proc means noprint data=unit ;
  by control ;
  var advunit advmeet ;
  output out=munit2 sum=numadv2 advmtm2 ;

/* merge number of unit info with unit sample */

data munit ;
  set sumunit ;
  keep control white numadv advmtm ;

data unit ;
  merge unit (in=q1) munit ;
  by control white;
  if q1 ;

data unit ;
  merge unit (in=q1) munit2 ;
  by control ;
  if q1 ;

/* create sample of advertised units for analysis
of rent and security deposit */

data advunit ;
  set unit ;
  count=1 ;

/* only keep unit if it is the advertised unit, there is only
one advertised unit for this tester and two advertised units
for the pair.  Or keep if the same conditions met for an
advertised unit that meets the testers needs */ 

  if advunit=1 and numadv=1 and numadv2=2 then output advunit ;
    else if advmeet=1 and  advmtm=1 and advmtm2=2 then output advunit ;
    else delete ;
  keep control white  advrent advsec ;

proc sort ;
  by control white ;

data munits1 ;         
   set advunit ;       
   madvrent=advrent ;  
   madvsec=advsec ;  
   if white=0 then output munits1 ;
   else delete ;
   keep control madvrent madvsec ;

proc sort data=munits1   ;
  by control ;

data munits2 ;
   set sumunit ;
   mnuminsp=numinsp ;                                       
   madvmtm=advmtm ;                                         
   madvmtm2=advmtm2 ;                                       
   madvacc=advaccm ;                                        
   madvacc2=advaccm2 ;                                      
   madvinsp=advinsp ;                                       
   mnumacc=numacc ;                                         
   mnumacc2=numacc2 ;                                       
   mnumsim=numsim ;                                         
   mnumsim2=numsim2 ;                                       
   msiminsp=siminsp ;                                       
   msimins2=siminsp2 ;                                      
   mfeereq=rfeereq ;
   mspcl=rspcl ;
   if white=0 then output munits2 ;
   else delete ;
   keep control  mnuminsp    madvmtm    madvmtm2  
     madvacc    madvacc2    madvinsp    mnumacc    mnumacc2 
     mnumsim    mnumsim2    msiminsp    msimins2  
     mfeereq mspcl  ;       

proc sort data=munits2   ;
  by control ;
/*---------------------------*/

data munits3 ; set follow ;
   mfollow=follow ;
   if white=0 then output munits3 ;
   else delete ;
   keep control mfollow ;

proc sort data=munits3   ;
  by control ;
/*---------------------------*/
data tests ; set tests ;

proc sort ;
by control  ;

/*---------------------------*/

data tests ;
  merge tests (in=q1) munits1 (in=q4) munits2 (in=q2) munits3 (in=q3) ;
    by control  ;
    if q1 ;

/* second visit */

data wunits1 ;         
   set advunit ;       
   wadvrent=advrent ;  
   wadvsec=advsec ;  
   if white=1 then output wunits1 ;
   else delete ;
   keep control wadvrent wadvsec ;

proc sort data=wunits1   ;
  by control ;


data wunits2 ; set sumunit ;
   wnuminsp=numinsp ;                                       
   wadvmtm=advmtm ;                                         
   wadvmtm2=advmtm2 ;                                       
   wadvacc=advaccm ;                                        
   wadvacc2=advaccm2 ;                                      
   wadvinsp=advinsp ;                                       
   wnumacc=numacc ;                                         
   wnumacc2=numacc2 ;                                       
   wnumsim=numsim ;                                         
   wnumsim2=numsim2 ;                                       
   wsiminsp=siminsp ;                                       
   wsimins2=siminsp2 ;                                      
   wfeereq=rfeereq ;
   wspcl=rspcl ;
   keep control  wnuminsp    wadvmtm    wadvmtm2  
     wadvacc    wadvacc2    wadvinsp    wnumacc    wnumacc2 
     wnumsim    wnumsim2    wsiminsp    wsimins2  
     wfeereq    wspcl  ;       
   if white=1 then output wunits2 ;
   else delete ;

proc sort data=wunits2   ;
  by control  ;
/*---------------------------*/
data wunits3 ; set follow ;
   wfollow=follow ;
   if white=1 then output wunits3 ;
   else delete ;
   keep control  wfollow ;

proc sort data=wunits3   ;
  by control  ;
/*---------------------------*/

data tests ; set tests ;
proc sort ;
by control  ;

/*---------------------------*/

data tests ;
  merge tests (in=q1) wunits1 (in=q4) wunits2 (in=q2) wunits3 (in=q3) ;
    by control  ;
    if q1 ;

/* create treatment variables */

/* replace missing variables with zero for no treatment */ 

  if wnuminsp=. then wnuminsp=0 ;
  if wadvinsp=. then wadvinsp=0 ;
  if wsiminsp=. then wsiminsp=0 ;
  if wsimins2=. then wsimins2=0 ;
  if wadvmtm=. then wadvmtm=0 ;
  if wadvmtm2=. then wadvmtm2=0 ;
  if wadvacc=. then wadvacc=0 ;
  if wadvacc2=. then wadvacc2=0 ;
  if wnumsim=. then wnumsim=0 ;
  if wnumsim2=. then wnumsim2=0 ;
  if wnumacc=. then wnumacc=0 ;
  if wnumacc2=. then wnumacc2=0 ;
  if wfollow=. then wfollow=0 ;

  if mnuminsp=. then mnuminsp=0 ;
  if madvinsp=. then madvinsp=0 ;
  if msiminsp=. then msiminsp=0 ;
  if msimins2=. then msimins2=0 ;
  if madvmtm=. then madvmtm=0 ;
  if madvmtm2=. then madvmtm2=0 ;
  if madvacc=. then madvacc=0 ;
  if madvacc2=. then madvacc2=0 ;
  if mnumsim=. then mnumsim=0 ;
  if mnumsim2=. then mnumsim2=0 ;
  if mnumacc=. then mnumacc=0 ;
  if mnumacc2=. then mnumacc2=0 ;
  if mfollow=. then mfollow=0 ;


/* advertised unit available */

  if wavladv=1 then wavailad=1 ;
    else if wavladv=2 then wavailad=0 ;
    else if wadvmtm>0 then wavailad=1 ;
    else wavailad=0 ;
  wavaila2=wavailad ;
  if wadvmtm2>0 then wavaila2=1 ;

  if mavladv=1 then mavailad=1 ;
    else if mavladv=2 then mavailad=0 ;
    else if madvmtm>0 then mavailad=1 ;
    else mavailad=0 ;
  mavaila2=mavailad ;
  if madvmtm2>0 then mavaila2=1 ;

/* similar unit available */

  if wsmbed=1 then wavailsm=1 ;
    else if wsmbed=2 then wavailsm=0 ;
    else if wnumsim>0 then wavailsm=1 ;
      else wavailsm=0 ;
  wavails2=wavailsm ;
  if wnumsim2>0 then wavails2=1 ;
  

  if msmbed=1 then mavailsm=1 ;
    else if msmbed=2 then mavailsm=0 ;
    else if mnumsim>0 then mavailsm=1 ;
      else mavailsm=0 ;
  mavails2=mavailsm ;
  if mnumsim2>0 then mavails2=1 ;

/*  Advertised unit inspected */

   if wadvinsp=0 then winspadv=0 ;
     else winspadv=1 ;
   if madvinsp=0 then minspadv=0 ;
     else minspadv=1 ;

   if wadvinsp>0 and wadvmtm>0 then winspad1=1 ;
     else winspad1=0 ;
   if madvinsp>0 and madvmtm>0 then minspad1=1 ;
     else minspad1=0 ;

   if wadvinsp>0 and wadvmtm2>0 then winspad2=1 ;
     else winspad2=0 ;
   if madvinsp>0 and madvmtm2>0 then minspad2=1 ;
     else minspad2=0 ;


/*  Similar unit inspected */

   if wsiminsp=0 then winspsim=0 ;
     else winspsim=1 ;
   if wsimins2=0 then winspsi2=0 ;
     else winspsi2=1 ;

   if msiminsp=0 then minspsim=0 ;
     else minspsim=1 ;
   if msimins2=0 then minspsi2=0 ;
     else minspsi2=1 ;

/*  Number of units recommended */

   if wtotunit<0 then wtotunit=. ;
   if mtotunit<0 then mtotunit=. ;

   if wtotunit^=. then wrecom=wtotunit ;
     else wrecom=wadvmtm+wadvacc+wnumsim+wnumacc ;
   if wtotunit^=. then wrecom2=wtotunit ;
     else wrecom2=wadvmtm2+wadvacc2+wnumsim2+wnumacc2 ;

   if mtotunit^=. then mrecom=mtotunit ;
     else mrecom=madvmtm+madvacc+mnumsim+mnumacc ;
   if mtotunit^=. then mrecom2=mtotunit ;
     else mrecom2=madvmtm2+madvacc2+mnumsim2+mnumacc2 ;


  mrecomi=0 ;
  wrecomi=0 ;
  if mrecom>wrecom then mrecomi=1 ;
    else if mrecom<wrecom then wrecomi=1 ; 

  mrecomi2=0 ;
  wrecomi2=0 ;
  if mrecom2>wrecom2 then mrecomi2=1 ;
    else if mrecom2<wrecom2 then wrecomi2=1 ; 

/*  Number of units inspected */

  minspect=mnuminsp ;
  winspect=wnuminsp ;

  minspcti=0 ;
  winspcti=0 ;
  if minspect>winspect then minspcti=1 ;
    else if minspect<winspect then winspcti=1 ; 

/*  Agent asked about income */

   if wqinc=1 then waskinc=1 ;
       else waskinc=0 ;

   if mqinc=1 then maskinc=1 ;
       else maskinc=0 ;

/*  Agent qualified tester */

   if magqual=1 then mqual=1 ;
      else mqual=0 ;
   if wagqual=1 then wqual=1 ;
      else wqual=0 ;

/*  Invitation to complete applications */

   if winvtapp=1 then waskfill=1 ;
       else waskfill=0 ;

   if minvtapp=1 then maskfill=1 ;
       else maskfill=0 ;

/*  Tester asked to callback */

   if warngm2=1 then wcallbak=1 ;
       else wcallbak=0 ;

   if marngm2=1 then mcallbak=1 ;
       else mcallbak=0 ;


/*  No provision made for future contact */

   if warngm3=1 then wnofutcn=1 ;
       else wnofutcn=0 ;

   if marngm3=1 then mnofutcn=1 ;
       else mnofutcn=0 ;

/* credit check required */

  if wcredchk^=1 then wcredchk=0 ;
  if mcredchk^=1 then mcredchk=0 ;

/*  Told about waiting list */

  if wwait=2 or wwait=0 then wwaitlst=0 ;
    else  wwaitlst=1 ;

  if mwait=2 or mwait=0 then mwaitlst=0 ;
    else mwaitlst=1 ;


/*  Suggest different complex */

  if wsugdiff=1 then wsugdiff=1 ;
    else wsugdiff=0 ;

  if msugdiff=1 then msugdiff=1 ;
    else msugdiff=0 ;

/*  Was an application fee required */

   if wfeereq>0 and wfeereq^=. then wfeereq=1 ;
   if mfeereq>0 and mfeereq^=. then mfeereq=1 ;

   if wfeereq=1 then wappfee=1 ;
     else if wfeereq=0 then wappfee=0 ;
   
   if mfeereq=1 then mappfee=1 ;
     else if mfeereq=0 then mappfee=0 ;

/*  Any special incentives offered */

   if wspcl>0 and wspcl^=. then wspcl=1 ; 
   if mspcl>0 and mspcl^=. then mspcl=1 ; 

   if wspcl=1 then wincent=1 ;
     else if wspcl=0 then wincent=0 ;

   if mspcl=1 then mincent=1 ;
     else if mspcl=0 then mincent=0 ;

/*  Monthly rent */

   if wadvrent=0 then wrentad=. ;
     else wrentad=wadvrent ;

   if madvrent=0 then mrentad=. ;
     else mrentad=madvrent ;

  mrentadi=0 ;
  wrentadi=0 ;
  if mrentad>wrentad then mrentadi=1 ;
  if mrentad<wrentad then wrentadi=1 ; 
  if mrentad=. or wrentad=. then do ;
       mrentadi=. ;
       wrentadi=. ;
       mrentad=. ;
       wrentad=. ;
      end ;

/*  security deposit - note that the continuous/numeric information
  on security deposit in dollars is used before any information on the
  number of months of security deposit  */

     if wadvsec^=. then wsecdep=wadvsec ;  
       else wsecdep=. ;

     if madvsec^=. then msecdep=madvsec ;  
       else msecdep=. ;

  msecdepi=0 ;
  wsecdepi=0 ;
  if msecdep>wsecdep then msecdepi=1 ;
  if msecdep<wsecdep then wsecdepi=1 ; 
  if msecdep=. or wsecdep=. then do ;
       msecdepi=. ;
       wsecdepi=. ;
       msecdep=. ;
       wsecdep=. ;
      end ;


keep control ngroup nsite type order mtestid wtestid 
  wavailad mavailad wavailsm mavailsm winspadv minspadv winspad1
  wavaila2 mavaila2 wavails2 mavails2 winspad2 minspad2 minspad1
  winspsim minspsim winspect minspect wrecom mrecom 
  winspsi2 minspsi2 wrecom2 mrecom2 wrecomi2 mrecomi2 
  winspcti minspcti wrecomi mrecomi 
  waskfill maskfill  wcallbak mcallbak 
  wnofutcn mnofutcn wfollow mfollow wqual mqual
  wrentad mrentad wsecdep msecdep wrentadi mrentadi 
  wsecdepi msecdepi wappfee mappfee wincent mincent 
  wcredchk mcredchk wspcl mspcl wfeereq mfeereq ;


proc sort ;
  by mtestid ;
data tests ;
  merge tests (in=q1) tester skintone ; if q1 ;
    by mtestid ;

proc freq ;
  tables maccent*ngroup masiang*ngroup mrank*ngroup ;

proc freq ;
  tables   order wincent*mincent 
           wcredchk*mcredchk 
           wappfee*mappfee 
           wavailad*mavailad 
           wavaila2*mavaila2 
           wavailsm*mavailsm 
           wavails2*mavails2 
           winspadv*minspadv 
           winspad1*minspad1
           winspad2*minspad2 
           winspsim*minspsim 
           winspsi2*minspsi2 
           wrecomi*mrecomi 
           wrecomi2*mrecomi2 
           winspcti*minspcti 
           waskfill*maskfill 
           wcallbak*mcallbak 
           wnofutcn*mnofutcn 
           wfollow*mfollow 
           wqual*mqual
           wrentadi*mrentadi 
           wsecdepi*msecdepi ;


/* save results to a permenant sas data set */

data hds2000.mrgrp2 ;
  set tests ; 


run;


