***************************************************************         
* Program name:  rental_output_sign.sas                                  
* Project:       Housing Discrimination Study Phase II                  
*                                                                       
*  Final version: October 14, 2002 by Steve Ross                         
*                                                                       
*  This program performs the sign test for metro report cards           
*  that were generated in rental_output2.sas.  The results are found in  
*  table format in the sas list file, rental_output_sign.lst.                  
*                                                                       
* Input Files:   fnrntmr2.ssd01, mrgrp2.ssd01, msap0hds.ssd01
*                                                                       
* Output Files:  none                                                   
*                                                                       
****************************************************************;       

options nocenter ;

libname hds '/mnt/jayhawk/jayproj/hds2000p2' ;
libname hdsp1 '/mnt/jayhawk/jayproj/hds2000' ;


filename fnrntmr2 '/mnt/jayhawk/jayproj/hds2000/fnrntmr2.ssd01' ;
filename mrgsp2 '/mnt/jayhawk/jayproj/hds2000p2/mrgsp2.ssd01' ;
filename MSAP0HDS '/mnt/jayhawk/jayproj/hds2000p2/MSAP0HDS.ssd01' ;


/* load data containing site weights based on advertisement 
   volume */

data weight ;
  set hds.MSAP0HDS ;
  nsite=sitecode ;
  if ETHNGRP='BLACK' then ngroup='1' ;
    else if ETHNGRP='HISPA' then ngroup='2' ;
    else if ETHNGRP='ASIPI' or ETHNGRP='ASICH' or       
     ETHNGRP='ASIKO' or ETHNGRP='ASIHM' then ngroup='3' ;  

   wpop=ETHNPOP0 ;

  if nsite='AN' then nsite='AH' ;
  if ngroup='3' and nsite^='LA' and nsite^='MN' 
            then result='ANatnl' ;  
  if ngroup='1' then do ;
    if nsite='MI' then result='BMiami' ;
    if nsite='BA' then result='BBalti' ;
    if nsite='PH' and HDSPH1=1 then result='BPhill' ;
    if nsite='PT' and HDSPH1=1 then result='BPitt ' ;
    if nsite in ('BR', 'MB', 'MY', 'HU') then result='BAlbma' ;
    if nsite in ('AG', 'AT', 'CO', 'MA', 'SV') then result='BGgia ' ;
    if nsite in ('BU', 'NS', 'NY', 'RO') then result='BNYork' ;
    if nsite in ('LA', 'OK', 'RV', 'SD', 'SF') then result='BCalfn' ;
    end ;
  if ngroup='2' then do ;
    if nsite='MI' then result='HMiami' ;
    if nsite in ('AH', 'LA', 'OK', 'RV', 'SD', 'SF', 'SJ') then 
            result='HCalfn' ;
    end ;    

  if result='' then delete ;
    else output weight ;

  keep nsite ngroup wpop result ;

/* scale weights, wpop, so that sum of weights for each
site grouping equals one */  

proc sort ;
  by ngroup result nsite ;

proc means noprint ;
  var wpop ;
    by ngroup result ;
  output out=tweight sum=tpop ;


data weight ;
  merge weight tweight ;
    by ngroup result ;
  wpop=wpop/tpop ;


/* read in phase 1 and phase 2 data */

data hds1 ;
  set hdsp1.fnrntmr2 ;

  if nsite='NY' and ngroup='2' then delete ;
  else if nsite in ('AT', 'BR', 'LA', 'LC', 'LK', 'MA', 'NY', 'SD', 'MS',
        'PH', 'PT') then output hds1 ;
  else delete ;

data hds2 ;
  set hds.mrgrp2 ;


data hds ;
  set hds1 hds2 ;

  if ngroup='3' then result='ANatnl' ;
  if ngroup='1' then do ;
    if nsite='MI' then result='BMiami' ;
    if nsite='BA' then result='BBalti' ;
    if nsite='PH' then result='BPhill' ;
    if nsite='PT' then result='BPitt ' ;
    if nsite in ('BR', 'MB', 'MY', 'HU') then result='BAlbma' ;
    if nsite in ('AG', 'AT', 'CO', 'MA', 'SV') then result='BGgia ' ;
    if nsite in ('BU', 'NS', 'NY', 'RO') then result='BNYork' ;
    if nsite in ('LA', 'OK', 'RV', 'SD', 'SF') then result='BCalfn' ;
    end ;
  if ngroup='2' then do ;
    if nsite='MI' then result='HMiami' ;
    if nsite in ('AH', 'LA', 'OK', 'RV', 'SD', 'SF', 'SJ') then 
            result='HCalfn' ;
    end ;    

  count=1 ;


proc sort ;
  by ngroup result nsite ;

data hds ;
  merge hds (in=q1) weight ;
    by ngroup result nsite ; if q1 ; 
  count=1 ;
  if wrentadi=. then rcount=0 ;
    else rcount=1 ;
  if wsecdepi=. then scount=0 ;
    else scount=1 ;
  if wincent=. or mincent=. then tcount=0 ;
    else tcount=1 ;

proc freq ;
  tables count rcount scount tcount ;

/* calculate the number of valid tests per site for relevant
variables */


proc means noprint ; 
  var count rcount scount tcount ;
    by ngroup result nsite ; 
  output out=cnt00 sum=num00 num00r num00s num00t ;


proc means noprint data=hds; 
  var count  rcount scount tcount ;
    by ngroup result ; 
  output out=cnttot sum=numtot numtotr numtots numtott ;


data hds ;
  merge  hds cnt00 ;
    by ngroup result nsite ; 

data hds ;
  merge  hds cnttot ;
    by ngroup result ; 

/* create discrete variables for each treatment based on four 
possible outcomes:  both favored, white favored, minority 
favored, and neither favored.  Record neither favored if
we cannot distinguish between both or neither. */

avail11=0 ; avail10=0 ; avail01=0 ; availc=1 ;
if wavailad=1 and mavailad=1 then avail11=1 ;
  else if wavailad=1 and mavailad=0 then avail10=1 ;
  else if wavailad=0 and mavailad=1 then avail01=1 ;

avlsm11=0 ; avlsm10=0 ; avlsm01=0 ; avlsmc=1 ;
if wavailsm=1 and mavailsm=1 then avlsm11=1 ;
  else if wavailsm=1 and mavailsm=0 then avlsm10=1 ;
  else if wavailsm=0 and mavailsm=1 then avlsm01=1 ;

recom11=0 ; recom10=0 ; recom01=0 ; recomc=1 ;
if wrecomi=1 and mrecomi=1 then recom11=1 ;
  else if wrecomi=1 and mrecomi=0 then recom10=1 ;
  else if wrecomi=0 and mrecomi=1 then recom01=1 ;

  /* hierarchical composite for access */

waccess=0 ; maccess=0 ; 
if avail10=1 then waccess=1 ;
  else if avail01=1 then maccess=1 ;
  else if avlsm10=1 then waccess=1 ;
  else if avlsm01=1 then maccess=1 ;
  else if recom10=1 then waccess=1 ;
  else if recom01=1 then maccess=1 ;


  /* consistency composite for access */


wacccns=0 ; macccns=0 ; 
if (avail10=1 or avlsm10=1 or recom10=1) then wacccns=1 ;
if (avail01=1 or avlsm01=1 or recom01=1) then macccns=1 ;

  
inspad11=0 ; inspad10=0 ; inspad01=0 ; inspadc=1 ;
if winspadv=1 and minspadv=1 then inspad11=1 ;
  else if winspadv=1 and minspadv=0 then inspad10=1 ;
  else if winspadv=0 and minspadv=1 then inspad01=1 ;

inspsm11=0 ; inspsm10=0 ; inspsm01=0 ; inspsmc=1 ;
if winspsim=1 and minspsim=1 then inspsm11=1 ;
  else if winspsim=1 and minspsim=0 then inspsm10=1 ;
  else if winspsim=0 and minspsim=1 then inspsm01=1 ;

inspct11=0 ; inspct10=0 ; inspct01=0 ; inspctc=1 ;
if winspcti=1 and minspcti=1 then inspct11=1 ;
  else if winspcti=1 and minspcti=0 then inspct10=1 ;
  else if winspcti=0 and minspcti=1 then inspct01=1 ;

  /* hierarchical composite for inspection */

waccss2=0 ; maccss2=0 ;
if inspad10=1 then waccss2=1 ;
else if inspad01=1 then maccss2=1 ;
else if inspsm10=1 then waccss2=1 ;
else if inspsm01=1 then maccss2=1 ;
else if inspct10=1 then waccss2=1 ;
else if inspct01=1 then maccss2=1 ;

  /* consistency composite for inspection */

wacc2cns=0 ; macc2cns=0 ;
if (inspad10=1 or inspsm10=1 or inspct10=1) then wacc2cns=1 ;
if (inspad01=1 or inspsm01=1 or inspct01=1) then macc2cns=1 ;

                                                       
askfil11=0 ; askfil10=0 ; askfil01=0 ; askfilc=1 ;     
if waskfill=1 and maskfill=1 then askfil11=1 ;         
  else if waskfill=1 and maskfill=0 then askfil10=1 ;  
  else if waskfill=0 and maskfill=1 then askfil01=1 ;  
                                                       
nofutc11=0 ; nofutc10=0 ; nofutc01=0 ; nofutcc=1 ;
if wnofutcn=1 and mnofutcn=1 then nofutc11=1 ;
  else if wnofutcn=1 and mnofutcn=0 then nofutc01=1 ;
  else if wnofutcn=0 and mnofutcn=1 then nofutc10=1 ;

follow11=0 ; follow10=0 ; follow01=0 ; followc=1 ;
if wfollow=1 and mfollow=1 then follow11=1 ;
  else if wfollow=1 and mfollow=0 then follow10=1 ;
  else if wfollow=0 and mfollow=1 then follow01=1 ;

qual11=0 ; qual10=0 ; qual01=0 ; qualc=1 ;
if wqual=1 and mqual=1 then qual11=1 ;
  else if wqual=1 and mqual=0 then qual10=1 ;
  else if wqual=0 and mqual=1 then qual01=1 ;

crdchk11=0 ; crdchk10=0 ; crdchk01=0 ; crdchkc=1 ;
if wcredchk=1 and mcredchk=1 then crdchk11=1 ;
  else if wcredchk=1 and mcredchk=0 then crdchk01=1 ;
  else if wcredchk=0 and mcredchk=1 then crdchk10=1 ;


  /* hierarchical composite for service  */

wservice=0 ; mservice=0 ;
if follow10=1 then wservice=1 ;           
  else if follow01=1 then mservice=1 ;    
  else if askfil10=1 then wservice=1 ;    
  else if askfil01=1 then mservice=1 ;    
  else if crdchk10=1 then wservice=1 ;
  else if crdchk01=1 then mservice=1 ;
  else if nofutc10=1 then wservice=1 ;    
  else if nofutc01=1 then mservice=1 ;    
                                          
  /* consistency composite for service  */


mservcns=0 ; wservcns=0 ;
if (follow10=1 or nofutc10=1 or askfil10=1
   or crdchk10) then wservcns=1 ;
if (follow01=1 or nofutc01=1 or askfil01=1
   or crdchk01=1) then mservcns=1 ;


appfee11=0 ; appfee10=0 ; appfee01=0 ; appfeec=1 ;            
if wappfee=1 and mappfee=1 then appfee11=1 ;                  
  else if wappfee=1 and mappfee=0 then appfee01=1 ;           
  else if wappfee=0 and mappfee=1 then appfee10=1 ;           
  else if wappfee=. or mappfee=. then do ;                    
     appfee11=. ; appfee10=. ; appfee01=. ; appfeec=0 ;       
     end ;                                                    
                                                              
incent11=0 ; incent10=0 ; incent01=0 ; incentc=1 ;            
if wincent=1 and mincent=1 then incent11=1 ;                  
  else if wincent=1 and mincent=0 then incent10=1 ;           
  else if wincent=0 and mincent=1 then incent01=1 ;           
  else if wincent=. or mincent=. then do ;
    incent11=. ; incent10=. ; incent01=. ; incentc=0 ;
    end ;                                             
                 
rentad11=0 ; rentad10=0 ; rentad01=0; rentadc=1 ;             
if wrentadi=1 and mrentadi=1 then rentad11=1 ;                
  else if wrentadi=1 and mrentadi=0 then rentad01=1 ;         
  else if wrentadi=0 and mrentadi=1 then rentad10=1 ;         
  else if wrentadi=. or mrentadi=. then do ;                  
     rentad11=. ; rentad10=. ; rentad01=.; rentadc=0 ;        
     end ;

secdep11=0 ; secdep10=0 ; secdep01=0 ; secdepc=1 ;        
if wsecdepi=1 and msecdepi=1 then secdep11=1 ;            
  else if wsecdepi=1 and msecdepi=0 then secdep01=1 ;     
  else if wsecdepi=0 and msecdepi=1 then secdep10=1 ;     
  else if wsecdepi=. or msecdepi=. then do ;              
     secdep11=. ; secdep10=. ; secdep01=. ; secdepc=0 ;   
     end ;                                                

/* heirarchical composite for terms */

mterms=0 ; wterms=0 ;                  
if rentad10=1 then wterms=1 ;          
  else if rentad01=1 then mterms=1 ;   
  else if incent10=1 then wterms=1 ;   
  else if incent01=1 then mterms=1 ;   
  else if secdep10=1 then wterms=1 ;   
  else if secdep01=1 then mterms=1 ;   
  else if appfee10=1 then wterms=1 ;   
  else if appfee01=1 then mterms=1 ;   
                                       
/* consistency composite for terms */

mtrmcns=0 ; wtrmcns=0 ;                                                     
if (rentad10=1 or incent10=1 or secdep10=1 or appfee10=1) then wtrmcns=1 ;  
if (rentad01=1 or incent01=1 or secdep01=1 or appfee01=1) then mtrmcns=1 ;  



access11=0 ; access10=0 ; access01=0 ; accessc=1 ;
if waccess=1 and maccess=1 then access11=1 ;
if waccess=1 and maccess=0 then access10=1 ;
if waccess=0 and maccess=1 then access01=1 ;

accss211=0 ; accss210=0 ; accss201=0 ; accss2c=1 ;
if waccss2=1 and maccss2=1 then accss211=1 ;
if waccss2=1 and maccss2=0 then accss210=1 ;
if waccss2=0 and maccss2=1 then accss201=1 ;

servic11=0 ; servic10=0 ; servic01=0 ; servicc=1 ;
if wservice=1 and mservice=1 then servic11=1 ;
if wservice=1 and mservice=0 then servic10=1 ;
if wservice=0 and mservice=1 then servic01=1 ;

terms11=0 ; terms10=0 ; terms01=0 ; termsc=1 ;
if wterms=1 and mterms=1 then terms11=1 ;
if wterms=1 and mterms=0 then terms10=1 ;
if wterms=0 and mterms=1 then terms01=1 ;

acccns11=0 ; acccns10=0 ; acccns01=0 ; acccnsc=1 ;
if wacccns=1 and macccns=1 then acccns11=1 ;
if wacccns=1 and macccns=0 then acccns10=1 ;
if wacccns=0 and macccns=1 then acccns01=1 ;

ac2cns11=0 ; ac2cns10=0 ; ac2cns01=0 ; ac2cnsc=1 ;
if wacc2cns=1 and macc2cns=1 then ac2cns11=1 ;
if wacc2cns=1 and macc2cns=0 then ac2cns10=1 ;
if wacc2cns=0 and macc2cns=1 then ac2cns01=1 ;

srvcns11=0 ; srvcns10=0 ; srvcns01=0 ; srvcnsc=1 ;
if wservcns=1 and mservcns=1 then srvcns11=1 ;
if wservcns=1 and mservcns=0 then srvcns10=1 ;
if wservcns=0 and mservcns=1 then srvcns01=1 ;

trmcns11=0 ; trmcns10=0 ; trmcns01=0 ; trmcnsc=1 ;
if wtrmcns=1 and mtrmcns=1 then trmcns11=1 ; 
if wtrmcns=1 and mtrmcns=0 then trmcns10=1 ; 
if wtrmcns=0 and mtrmcns=1 then trmcns01=1 ; 

/* overall consistency composite */

cnsty11=0 ; cnsty10=0 ; cnsty01=0 ; cnstyc=1 ;
if (wtrmcns=1 or wservcns=1 or wacccns=1 or wacc2cns=1) and
   (mtrmcns=1 or mservcns=1 or macccns=1 or macc2cns=1)
      then cnsty11=1 ; 
else if (wtrmcns=1 or wservcns=1 or wacccns=1 or wacc2cns=1)
     and mtrmcns=0 and
     mservcns=0 and macccns=0 and macc2cns=0  then cnsty10=1 ;
else if (mtrmcns=1 or mservcns=1 or macccns=1 or macc2cns=1)
     and wtrmcns=0 and
     wservcns=0 and wacccns=0 and wacc2cns=0  then cnsty01=1 ;

/* variable by variable construction of composite indicator */

heir11=0 ; heir10=0 ; heir01=0 ; heirc=1 ;
if avail10=1 then do ; 
  heir10=1 ;
  end ;
  else if avail01=1 then do ; 
  heir01=1 ;
  end ;
  else if inspad10=1 then do ;
  heir10=1 ;
  end ;
  else if inspad01=1 then do ;
  heir01=1 ;
  end ;
  else if rentad10=1 then do ;
  heir10=1 ;
  end ;
  else if rentad01=1 then do ;
  heir01=1 ;
  end ;
  else if avlsm10=1 then  do ;
  heir10=1 ;
  end ;
  else if avlsm01=1 then  do ;
  heir01=1 ;
  end ;
  else if inspsm10=1 then do ;
  heir10=1 ;
  end ;
  else if inspsm01=1 then do ;
  heir01=1 ;
  end ;
  else if recom10=1 then  do ;
  heir10=1 ;
  end ;
  else if recom01=1 then  do ;
  heir01=1 ;
  end ;
  else if inspct10=1 then do ;
  heir10=1 ;
  end ;
  else if inspct01=1 then do ;
  heir01=1 ;
  end ;
  else if incent10=1 then do ;
  heir10=1 ;
  end ;
  else if incent01=1 then do ;
  heir01=1 ;
  end ;
  else if secdep10=1 then do ;
  heir10=1 ;
  end ;
  else if secdep01=1 then do ;
  heir01=1 ;
  end ;
  else if appfee10=1 then do ; 
  heir10=1 ;
  end ;
  else if appfee01=1 then do ; 
  heir01=1 ;
  end ;
  else if follow10=1 then do ;
  heir10=1 ;
  end ;
  else if follow01=1 then do ;
  heir01=1 ;
  end ;
  else if askfil10=1 then do ; 
  heir10=1 ;
  end ;
  else if askfil01=1 then do ; 
  heir01=1 ;
  end ;
  else if crdchk10=1 then do ;
  heir10=1 ;
  end ;
  else if crdchk01=1 then do ;
  heir01=1 ;
  end ;
  else if nofutc10=1 then  do ;
  heir10=1 ;
  end ;
  else if nofutc01=1 then  do ;
  heir01=1 ;
  end ;
  else heir11=1 ;

/* black white tests */


data hds ;
   set hds ;

/* equal weights for sites  */
 
  if ngroup='3' then wght89=numtot/(12*num00) ; 
  if ngroup='1' then do ;
    if nsite='MI' then  wght89=numtot/num00 ;
    if nsite='BA' then  wght89=numtot/num00 ;
    if nsite='PH' then  wght89=numtot/num00 ;
    if nsite='PT' then  wght89=numtot/num00 ;
    if nsite in ('BR', 'MB', 'MY', 'HU') then wght89=numtot/(4*num00) ; 
    if nsite in ('AG', 'AT', 'CO', 'MA', 'SV') then wght89=numtot/(5*num00) ; 
    if nsite in ('BU', 'NS', 'NY', 'RO') then wght89=numtot/(4*num00) ; 
    if nsite in ('LA', 'OK', 'RV', 'SD', 'SF') then wght89=numtot/(5*num00) ; 
    end ;
  if ngroup='2' then do ;
    if nsite='MI' then wght89=numtot/num00 ;
    if nsite in ('AH', 'LA', 'OK', 'RV', 'SD', 'SF', 'SJ') then 
               wght89=numtot/(7*num00) ; 
    end ;    

/* population based weights for sites */

  nweight=wpop*numtot/num00 ;
  if wrentadi=. then rweight=0 ;
    else   rweight=wpop*numtotr/num00r ;
  if wsecdepi=. then sweight=0 ;
    else   sweight=wpop*numtots/num00s ;
  if wincent=. or mincent=. then tweight=0 ;
    else   tweight=wpop*numtott/num00t ;

  count=1 ;

davail=wavailad-mavailad ;

davlsm=wavailsm-mavailsm ;

drecom=wrecomi-mrecomi ;

daccess=waccess-maccess ;

dacccns=wacccns-macccns ;

dinspad=winspadv-minspadv ;

dinspsm=winspsim-minspsim ;

dinspct=winspcti-minspcti ;

daccss2=waccss2-maccss2 ;

dacc2cns=wacc2cns-macc2cns ;

drentad=wrentadi-mrentadi ;

dincent=wincent-mincent ;

dsecdep=wsecdepi-msecdepi ;

dappfee=wappfee-mappfee ;

dterms=wterms-mterms ;

dtrmcns=wtrmcns-mtrmcns ;

dfollow=wfollow-mfollow ;

daskfil=waskfill-maskfill ;

dcrdchk=crdchk10-crdchk01 ;

dnofutc=wnofutcn-mnofutcn ;

dservic=wservice-mservice ;

dservcns=wservcns-mservcns ;

dheir=heir10-heir01 ;

dcnsty=cnsty10-cnsty01 ;

  if result in ('BMiami','BBalti','BPhill','BPitt ','HMiami')
     then output hds  ;
  else delete ;


proc sort ;
    by ngroup result count ; 

/* conduct sign test for every type of test and metro area */

proc univariate  ;
  var davail davlsm drecom daccess dacccns
      dinspad dinspsm  dinspct daccss2 dacc2cns
      drentad dincent dsecdep dappfee dterms dtrmcns
      dfollow daskfil dcrdchk dnofutc dservic dservcns
      dheir dcnsty ;
    by ngroup result count ; 







run;







