****************************************************************
* Program name:  rental_units_p2.sas
* Author:        Steve Ross
* Final Version: October 4, 2002
* Project:       Housing Discrimination Study (#06977-000-00)
*
* This program reads the raw data from the units questions of the 
* rental site visit report form.  This data is cleaned and
* merged with the information on tester needs from the paired
* assignment sample.  
* 
* Input Files:	availuni.ssd01, assignp2.ssd01
* 
* Output Files:	unitsp2.ssd01 
*
****************************************************************;

options nocenter ;

libname hds2000 '/mnt/jayhawk/jayproj/hds2000p2' ;

filename assignp2 '/mnt/jayhawk/jayproj/hds2000p2/assignp2.ssd01' ;
filename availuni '/mnt/jayhawk/jayproj/hds2000p2/availuni.ssd01' ;
filename unitsp2 '/mnt/jayhawk/jayproj/hds2000p2/unitsp2.ssd01' ;

/* load information on rental units recommended or inspected */

data q17 ;
  set hds2000.availuni ;

  if raceid<20 then race=raceid-10 ;          
    else if raceid>30 then race=raceid-30 ;   
    else race=raceid -20 ;                    

   if delrec=1 or raceid>30 then delete ;
    else output q17 ;
   keep control seqau race raceid ruinsp ruinad ruavlbl rurent rubed
    rudepst rudepsts rutotfee ruspcl ;


proc sort ;
  by control race seqau ;

/* load sample of paired assignments */

data assign ;
  set hds2000.assignp2 ;

/* Generate average assignment information across testers.  
For lower price range, use lowest value across two testers
or the only value provided if missing for one tester.  If missing,
use zero.  For upper price range, same approach except use
highest of two values and 9999 if missing.  */

 wlocate=INDEX(waprice,'to') ;   
 if wlocate=5 then do ;        
   walrange=substr(waprice,1,4) ;  
   wahrange=substr(waprice,8,4) ;  
   wpricell=input(walrange,$4.) ;  
   wpricehl=input(wahrange,$4.) ;  
   end ;                        
 else if wlocate=6 then do ;   
   walrange=substr(waprice,1,4) ;  
   wahrange=substr(waprice,9,4) ;  
   wpricell=input(walrange,$4.) ;  
   wpricehl=input(wahrange,$4.) ;  
   end ;                        

 mlocate=INDEX(maprice,'to') ;   
 if mlocate=5 then do ;        
   malrange=substr(maprice,1,4) ;  
   mahrange=substr(maprice,8,4) ;  
   mpricell=input(malrange,$4.) ;  
   mpricehl=input(mahrange,$4.) ;  
   end ;                        
 else if mlocate=6 then do ;   
   malrange=substr(maprice,1,4) ;  
   mahrange=substr(maprice,9,4) ;  
   mpricell=input(malrange,$4.) ;  
   mpricehl=input(mahrange,$4.) ;  
   end ;                        


  if mpricell=. and wpricell=. then apricell=0.0 ;
    else if wpricell=. then apricell=mpricell ;
    else if mpricell=. then apricell=wpricell ;
    else if mpricell>wpricell then apricell=wpricell ;
    else apricell=mpricell ;
  
  if mpricehl=. and wpricehl=. then apricehl=9999 ;
    else if wpricehl=. then apricehl=mpricehl ;
    else if mpricehl=. then apricehl=wpricehl ;
    else if mpricehl>wpricehl then apricehl=mpricehl ;
    else apricehl=wpricehl ;

/* For minimum number of bedrooms, use lowest of two values
and set to zero if 0.5. */

  if mbedmin=. and wbedmin=. then abedmin=. ;
    else if mbedmin=. then abedmin=wbedmin ;
    else if wbedmin=. then abedmin=mbedmin ;  
    else if mbedmin<=wbedmin then abedmin=mbedmin ;
    else abedmin=wbedmin ;
  if abedmin<=0.5 then abedmin=0.0 ;


/* For upper and lower range of number of bedrooms required,
use highest value provided by either tester as upper limit
and lowest value for lower limit so that upper and lower limits
will be equal if testers assigned the same value or one tester
does not report a value */

  if mbedreq<0 then mbedreq=. ;
  if wbedreq<0 then wbedreq=. ;

  if mbedreq=. and wbedreq=. then do ;
       abedreql=. ;
       abedrequ=. ;
       end ;
    else if mbedreq=. then do ;
       abedreql=wbedreq ;
       abedrequ=wbedreq ;
       end ;
    else if wbedreq=. then do ;
       abedreql=mbedreq ;  
       abedrequ=mbedreq ;  
       end ;
    else if mbedreq<=wbedreq then do ;
       abedreql=mbedreq ;
       abedrequ=wbedreq ;
       end ;
    else do ;
       abedreql=wbedreq ;
       abedrequ=mbedreq ;
       end ;

/*  If fractional, set lower limit to integer just above and
upper limit to integer just below. */

  if abedreql=0.5 then abedreql=0.0 ;
  if abedreql=1.5 then abedreql=1.0 ;
  if abedreql=2.5 then abedreql=2.0 ;
  if abedrequ=0.5 then abedrequ=1.0 ;
  if abedrequ=1.5 then abedrequ=2.0 ;
  if abedrequ=2.5 then abedrequ=3.0 ;

  
    
/* Date housing required is constructed from year, month and day 
variables.  Set these valiables to missing if entries invalid, and 
change year so that all entries are consistent. */

  if mneed='7/1/01' then mneed='7/01/01' ;     
  if mneed='8/1/01' then mneed='8/01/01' ;     
  if mneed='9/1/01' then mneed='9/01/01' ;     
  if mneed='10/1/01' then mneed='10/01/01' ;   
  if mneed='11/1/01' then mneed='11/01/01' ;   
  if mneed='12/1/01' then mneed='12/01/01' ;   
                                                 
  mndloc=INDEX(mdate,'/') ;                      
  mphloc=INDEX(mneed,'/') ;                      
                                                 
  if mndloc=3 then do ;              
    mndmonth=substr(mdate,1,2) ;    
    if substr(mdate,5,1)='/' then mndday=substr(mdate,4,1) ;      
      else mndday=substr(mdate,4,2) ;      
    mndyear=substr(mdate,7,2) ;     
    end ;                           
  else if mndloc=2 then do ;         
    mndmonth=substr(mdate,1,1) ;    
    if substr(mdate,4,1)='/' then mndday=substr(mdate,3,1) ;      
      else mndday=substr(mdate,3,2) ;      
    mndyear=substr(mdate,6,2) ;     
    end ;                           
                                    
  mnddays=mndday+(mndmonth-1)*30 ;     
                                    
  if mphloc=3 then do ;              
    mphmonth=substr(mneed,1,2) ;    
    if substr(mneed,5,1)='/' then mphday=substr(mneed,4,1) ;      
      else mphday=substr(mneed,4,2) ;      
    mphyear=substr(mneed,7,2) ;     
    end ;                           
  else if mphloc=2 then do ;                     
    mphmonth=substr(mneed,1,1) ;                
    if substr(mneed,4,1)='/' then mphday=substr(mneed,3,1) ;      
      else mphday=substr(mneed,3,2) ;      
    mphyear=substr(mneed,6,2) ;                 
    end ;                                       
                                                
  if mphyear='01' then mphdays=mphday+(mphmonth-1)*30 ;             
    else if mphyear='02' then mphdays=mphday+(mphmonth-1)*30 + 365 ;

  mwkdays=23+4*30+7*(mweek-4) ;                     
                                                  
  mphdiff=mphdays - mnddays ;                        
                                                  
  if mnddays=. then mphdiff=mphdays - mwkdays ;       
  if mphdiff<0 or mphdiff=. then do ;
      mdate_y=. ;
      mdate_m=. ;
      mdate_d=. ;
      end ;
  else do ;      
      mdate_y=input(mphyear,$2.) ;  
      mdate_m=input(mphmonth,$2.) ;  
      mdate_d=input(mphday,$2.) ;  
      end ;


  if wneed='7/1/01' then wneed='7/01/01' ;     
  if wneed='8/1/01' then wneed='8/01/01' ;     
  if wneed='9/1/01' then wneed='9/01/01' ;     
  if wneed='10/1/01' then wneed='10/01/01' ;   
  if wneed='11/1/01' then wneed='11/01/01' ;   
  if wneed='12/1/01' then wneed='12/01/01' ;   
                                                 
  wndloc=INDEX(wdate,'/') ;                      
  wphloc=INDEX(wneed,'/') ;                      
                                                 
  if wndloc=3 then do ;              
    wndmonth=substr(wdate,1,2) ;    
    if substr(wdate,5,1)='/' then wndday=substr(wdate,4,1) ;      
      else wndday=substr(wdate,4,2) ;      
    wndyear=substr(wdate,7,2) ;     
    end ;                           
  else if wndloc=2 then do ;         
    wndmonth=substr(wdate,1,1) ;    
    if substr(wdate,4,1)='/' then wndday=substr(wdate,3,1) ;      
      else wndday=substr(wdate,3,2) ;      
    wndyear=substr(wdate,6,2) ;     
    end ;                           
                                    
  wnddays=wndday+(wndmonth-1)*30 ;     
                                    
  if wphloc=3 then do ;              
    wphmonth=substr(wneed,1,2) ;    
    if substr(wneed,5,1)='/' then wphday=substr(wneed,4,1) ;      
      else wphday=substr(wneed,4,2) ;      
    wphyear=substr(wneed,7,2) ;     
    end ;                           
  else if wphloc=2 then do ;                     
    wphmonth=substr(wneed,1,1) ;                
    if substr(wneed,4,1)='/' then wphday=substr(wneed,3,1) ;      
      else wphday=substr(wneed,3,2) ;      
    wphyear=substr(wneed,6,2) ;                 
    end ;                                       
                                                
  if wphyear='01' then wphdays=wphday+(wphmonth-1)*30 ;             
    else if wphyear='02' then wphdays=wphday+(wphmonth-1)*30 + 365 ;

  wwkdays=23+4*30+7*(wweek-4) ;                     
                                                  
  wphdiff=wphdays - wnddays ;                        
                                                  
  if wnddays=. then wphdiff=wphdays - wwkdays ;       
  if wphdiff<0 or wphdiff=. then do ;
      wdate_y=. ;
      wdate_m=. ;
      wdate_d=. ;
      end ;
  else do ;      
      wdate_y=input(wphyear,$2.) ;  
      wdate_m=input(wphmonth,$2.) ;  
      wdate_d=input(wphday,$2.) ;  
      end ;


/* use latest date provided by either tester */
  if wdate_y=. and mdate_y=. then do ;
    adate_y=. ;
    adate_m=. ;
    adate_d=. ;
    end ;
  else if wdate_y=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if mdate_y=. then do ;
    adate_y=wdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_y<mdate_y then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if wdate_y>mdate_y then do ;
    adate_y=wdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_m=. and mdate_m=. then do ;
    adate_y=mdate_y ;
    adate_m=. ;
    adate_d=. ;
    end ;
  else if wdate_m=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if mdate_m=. then do ;
    adate_y=wdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_m>mdate_m then do ;
    adate_y=wdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_m<mdate_m then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if wdate_d=. and mdate_d=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=. ;
    end ;
  else if wdate_d=. then do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;
  else if mdate_d=. then do ;
    adate_y=wdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else if wdate_d>mdate_d then do ;
    adate_y=wdate_y ;
    adate_m=wdate_m ;
    adate_d=wdate_d ;
    end ;
  else do ;
    adate_y=mdate_y ;
    adate_m=mdate_m ;
    adate_d=mdate_d ;
    end ;

   

  if substr(control,4,1)='R' then output assign ;
    else delete ;

  keep control apricehl apricell adate_y adate_m adate_d 
    abedmin abedreql abedrequ ;

proc contents ;

proc sort ;
  by control ;

proc sort data=q17 ; by control ;

/* merge assignment information into unit data */ 

data q17 ;
  merge q17 (in=q1) assign (in=q2) ;
    by control ; if q1=1 and q2=1 ;


data q17  ;
   set q17  ;

data hds2000.unitsp2 ;
  set q17 ;

  if rurent<100 then rurent=. ;
  if rudepsts<=1 then rudepsts=. ;

  ravlloc=INDEX(ruavlbl,'/') ;                      
                                                 
  if ravlloc=3 then do ;              
    ravmonth=substr(ruavlbl,1,2) ;    
    ravday=substr(ruavlbl,4,2) ;      
    ravyear=substr(ruavlbl,7,2) ;     
    end ;                           
  else if ravlloc=2 then do ;         
    ravmonth=substr(ruavlbl,1,1) ;    
    ravday=substr(ruavlbl,3,2) ;      
    ravyear=substr(ruavlbl,6,2) ;     
    end ;                           

  if ravmonth='00' and ravday='00' and ravyear='00' then do ;
    ravmonth='' ;
    ravday='' ;
    ravyear='' ;
    end ;
  if ravmonth='99' and ravday='99' and ravyear='99' then do ;
    ravmonth='' ;
    ravday='' ;
    ravyear='' ;
    end ;
  if substr(ravday,2,1)='/' then ravday=substr(ravday,1,1) ;
  if ravmonth='80' then ravmonth='08' ;
  if ravyear='00' then ravyear='01' ;
  if ravday='0' then ravday='01' ;

  ruavlbl3=0 ;
  ruavlbl1=0 ;
  ruavlbl2=0 ;

  ruavlbl3=input(ravyear,$2.) ;  
  ruavlbl1=input(ravmonth,$2.) ;  
  ruavlbl2=input(ravday,$2.) ;  

  
  keep control race ruinsp ruinad ruavlbl rurent rubed
    rudepst rudepsts rutotfee ruspcl ruavlbl3 ruavlbl2 ruavlbl1 
    apricehl apricell adate_y adate_m adate_d 
    abedmin abedreql abedrequ seqau ;

proc contents ;
                                                  
  proc freq ;
   tables ruavlbl3 ruavlbl2 ruavlbl1  ;


run ;

