****************************************************************   
* Program name:  rental_visit_p2.sas                                  
* Project:       Housing Discrimination Study Phase II		              
*                                                                  
*  Final version: Nov 11, 2002 by Steve Ross                   
*                                                                  
*  This program generates a clean sample of rental site            
*  visits for all testers.  The site visits for both the           
*  majority and minority testers are merged with the sample of     
*  paired assignments.  A final sample of completed rental 
*  tests is created where each tester made at least one visit 
*  to the real estate agency.                      
*                                                                  
* Input Files:   rental.ssd01, assignp2.ssd01
*                                                                  
* Output Files:  rentalp2.ssd01                                     
*                                                                  
*                                                                  
****************************************************************;  

options nocenter ;

/* ref lib */

libname hds2000 '/work/ross' ;

/* ref files */

filename rental '/work/ross/rental.ssd01' ;
filename assignp2 '/work/ross/assignp2.ssd01' ;

/* new file: salesp2.sas to salesp2.ssd01 */
filename rentalp2 '/work/ross/rentalp2.ssd01' ;

data rental ; set hds2000.rental ;

  count=1 ;

  if raceid<20 then race=raceid-10 ;
    else if raceid>30 then race=raceid-30 ;
    else race=raceid -20 ;

  if race=1 then white=1 ;
    else white=0 ;

proc freq ;
  tables raceid ;

data rental ;
  set rental ;
  if raceid>30 then delete ;
    else if raceid=7 then delete ;
    else output rental ;

proc sort ; by control white ;

/* keeping only rental tests */

data assign ; set hds2000.assignp2 ;

proc freq ;
  tables ntype ;

data assign ;
  set assign ;
  if ntype='R' then output assign ;
  else delete ;

proc sort ; by control ;


data wrvrf ;
  set rental ;

  if raceid<20 then order='1' ;
    else order='0' ;

  wtestid=testerid ;  
  wmeetag=rmeetag ;
  wavladv=ravlbad ;
  wsmbed=rsamebed ;
  wminbed=rminbed ;
  wtunit=rtotunit ;


  warngm1=rfcon1 ;
  warngm2=rfcon2 ;
  warngm3=rfcon3 ;
  warngm4=rfcon4 ;

  wcredchk=rcredchk ;
  wcrimchk=rcrimchk ;
  wagqual=ragqual ;
  wqmarry=rqmarry ;
  wqfamsiz=rqfamsiz ;
  wqinc=rqincome ;
  wqoccup=rqoccup ;
  wqempl=rqempln ;
  wqcredit=rqcredit ;

  wagmet1=ragmet1 ; 
  wagmet2=ragmet2 ;
  wagmet3=ragmet3 ;
  wagmet4=ragmet4 ;
  wagmet5=ragmet5 ;

  wagnam1=ragname1 ;
  wagnam2=ragname2 ;
  wagnam3=ragname3 ;
  wagnam4=ragname4 ;
  wagnam5=ragname5 ;
                        
  wvdate=rvdate ;       
  wvday=rvday ;         
                      
  winvtapp=rinvtapp ;   
  wsugdiff=rsugdiff ;   
  wappnec=rappnec ;
                      
  
  if white=1 then output wrvrf ;
  else delete ;
  keep control order wtestid wavladv wsmbed wminbed wtunit 
  warngm1 warngm2 warngm3 warngm4 wcredchk wcrimchk
  wagqual wqmarry wqfamsiz wqinc wqoccup wqempl 
  wagnam1 wagnam2 wagnam3 wagnam4 wagnam5  
  wagmet1 wagmet2 wagmet3 wagmet4 wagmet5 
  wvdate wvday winvtapp wsugdiff wappnec ;



data mrvrf ;
  set rental ;

  mtestid=testerid ;  
  mmeetag=rmeetag ;
  mavladv=ravlbad ;
  msmbed=rsamebed ;
  mminbed=rminbed ;
  mtunit=rtotunit ;

  marngm1=rfcon1 ;
  marngm2=rfcon2 ; 
  marngm3=rfcon3 ;
  marngm4=rfcon4 ;

  mcredchk=rcredchk ;
  mcrimchk=rcrimchk ;
  magqual=ragqual ;
  mqmarry=rqmarry ;
  mqfamsiz=rqfamsiz ;
  mqinc=rqincome ;
  mqoccup=rqoccup ;
  mqempl=rqempln ;
  mqcredit=rqcredit ;

  magmet1=ragmet1 ; 
  magmet2=ragmet2 ;
  magmet3=ragmet3 ;
  magmet4=ragmet4 ;
  magmet5=ragmet5 ;

  magnam1=ragname1 ;
  magnam2=ragname2 ;
  magnam3=ragname3 ;
  magnam4=ragname4 ;
  magnam5=ragname5 ;
                        
  mvdate=rvdate ;       
  mvday=rvday ;         
                      
  minvtapp=rinvtapp ;   
  msugdiff=rsugdiff ;   
  mappnec=rappnec ;
                      
  
  if white=0 then output mrvrf ;
  else delete ;
  keep control mtestid mavladv msmbed mminbed mtunit 
  marngm1 marngm2 marngm3 marngm4 mcredchk mcrimchk
  magqual mqmarry mqfamsiz mqinc mqoccup mqempl 
  magnam1 magnam2 magnam3 magnam4 magnam5  
  magmet1 magmet2 magmet3 magmet4 magmet5 
  mvdate mvday minvtapp msugdiff mappnec ;

 
/* merge minority treatment information with sample of tests */

data assign ;
  merge assign (in=q1) wrvrf (in=q2) mrvrf (in=q3) ;
  by control ;
  
  wrvrf=q2 ;
  mrvrf=q3 ;
 
  if q1 then output assign ;
  else delete ;

/* keep tests where a site visit was completed by both testers */

data hds2000.rentalp2 problem ; set assign ;
  nsite=substr(control,1,2) ;
  if  wrvrf=1  and mrvrf=1 then output hds2000.rentalp2 ;
  else output problem ;

proc freq data=hds2000.rentalp2 ;
  tables nsite*ngroup ;
run ;




