***************************************************************        
* Program name:  sales_output_state_S.sas                                
* Project:       Housing Discrimination Study Phase II                 
*                                                                      
*  Final version: October 14, 2002 by Steve Ross                        
*                                                                      
*  This program merges together information from the Phase             
*  I and II 2000 sales housing discrimination studies in order         
*  to conduct the sign test for the primary metro areas         
*  associated with each state report card.  The results are
*  to be used with the results from sales_output_state.sas
*  The results are found in table format in the sas list file, 
*  sales_output_state.lst.          
*                                                                      
* Input Files:   fnslsmr2.ssd01, mrgsp2.ssd01, MSAP0HDS.ssd01          
*       rsteer00.ssd01, isteer00.ssd01, rh_pctwh.ssd01, ih_pctwh.ssd01 
*                                                                      
* Output Files:  none                                                  
*                                                                      
****************************************************************;      
                                                                       
options nocenter ;

libname hds '/mnt/jayhawk/jayproj/hds2000p2' ;
libname hdsp1 '/mnt/jayhawk/jayproj/hds2000' ;


filename fnslsmr2 '/mnt/jayhawk/jayproj/hds2000/fnslsmr2.ssd01' ;
filename mrgsp2 '/mnt/jayhawk/jayproj/hds2000p2/mrgsp2.ssd01' ;
filename MSAP0HDS '/mnt/jayhawk/jayproj/hds2000p2/MSAP0HDS.ssd01' ;



filename rsteer00 '/mnt/jayhawk/jayproj/hds2000/rsteer00.ssd01' ;
filename isteer00 '/mnt/jayhawk/jayproj/hds2000/isteer00.ssd01' ;
filename rh_pctwh '/mnt/jayhawk/jayproj/hds2000p2/rh_pctwh.ssd01' ;
filename ih_pctwh '/mnt/jayhawk/jayproj/hds2000p2/ih_pctwh.ssd01' ;

/* steering data */

data rsteer00 ;
  set hdsp1.rsteer00 ;
  whtrec=wttrinc ;
  keep control whtrec ;

data isteer00 ;
  set hdsp1.isteer00 ;
  whtnspct=wttrinc ;
  keep control whtnspct ;

data rh_pctwh ;
  set hds.rh_pctwh ;
  whtrec=wttrinc ;
  keep control whtrec ;

data ih_pctwh ;
  set hds.ih_pctwh ;
  whtnspct=wttrinc ;
  keep control whtnspct ;

data rsteer ;
  set rsteer00 rh_pctwh ;
proc sort ;
  by control ;

data isteer ;
  set isteer00 ih_pctwh ;
proc sort ;
  by control ;


/* load data containing site weights based on advertisement 
   volume */

data weight ;
  set hds.MSAP0HDS ;
  nsite=sitecode ;
  if ETHNGRP='BLACK' then ngroup='1' ;
    else if ETHNGRP='HISPA' then ngroup='2' ;
    else if ETHNGRP='ASIPI' or ETHNGRP='ASICH' or       
     ETHNGRP='ASIKO' or ETHNGRP='ASIHM' then ngroup='3' ;  

   wpop=ETHNPOP0 ;

  if nsite='AN' then nsite='AH' ;
  if ngroup='1' then do ;
    if nsite in ('BR', 'MB', 'MY', 'HU') then result='BAlbma' ;
    if nsite in ('AG', 'AT', 'CO', 'MA', 'SV') then result='BGgia ' ;
    if nsite in ('BU', 'NS', 'NY', 'RO') then result='BNYork' ;
    if nsite in ('LA', 'OK', 'RV', 'SD', 'SF') then result='BCalfn' ;
    end ;
  if ngroup='2' then do ;
    if nsite in ('AH', 'LA', 'OK', 'RV', 'SD', 'SF', 'SJ') then 
            result='HCalfn' ;
    end ;    

  if nsite in ('BR', 'AT', 'NY', 'LA') then prime=1 ;
     else prime=0 ; 

  if result='' then delete ;
    else output weight ;

  keep nsite ngroup wpop result prime ;

/* scale weights, wpop, so that sum of weights for each
site grouping equals one */  

proc sort ;
  by ngroup result prime nsite ;

proc means noprint ;
  var wpop ;
    by ngroup result prime  ;
  output out=tweight sum=tpop ;


data weight ;
  merge weight tweight ;
    by ngroup result prime ;
  wpop=wpop/tpop ;


/* read in phase 1 and phase 2 data */

data hds1 ;
  set hdsp1.fnslsmr2 ;

  if nsite='NY' and ngroup='2' then delete ;
  else if nsite in ('AT', 'BR', 'LA', 'MA', 'NY', 'SD') then output hds1 ;
  else delete ;

data hds2 ;
  set hds.mrgsp2 ;
  if nsite in ('MB', 'MY', 'HU', 'AG', 'CO', 'BU', 'NS', 'RO',
       'OK', 'RV', 'SD', 'SF', 'AH', 'SJ', 'SV') then output hds2 ;
    else delete ;


data hds ;
  set hds1 hds2 ;

  count=1 ;

  if ngroup='1' then do ;
    if nsite in ('BR', 'MB', 'MY', 'HU') then result='BAlbma' ;
    if nsite in ('AG', 'AT', 'CO', 'MA', 'SV') then result='BGgia ' ;
    if nsite in ('BU', 'NS', 'NY', 'RO') then result='BNYork' ;
    if nsite in ('LA', 'OK', 'RV', 'SD', 'SF') then result='BCalfn' ;
    end ;
  if ngroup='2' then do ;
    if nsite in ('AH', 'LA', 'OK', 'RV', 'SD', 'SF', 'SJ') then 
            result='HCalfn' ;
    end ;    

  if nsite in ('BR', 'AT', 'NY', 'LA') then prime=1 ;
     else prime=0 ; 

  if result='' then delete ;
    else output hds ;


proc sort ;
  by ngroup result prime nsite ;

data hds ;
  merge hds (in=q1) weight ;
    by ngroup result prime nsite ; if q1 ; 
  count=1 ;


/* calculate the number of valid tests per site for relevant
variables */


proc means noprint ; 
  var count ;
    by ngroup result prime nsite ; 
  output out=cnt00 sum=num00 ;


proc means noprint data=hds; 
  var count  ;
    by ngroup result prime ; 
  output out=cnttot sum=numtot ;


data hds ;
  merge  hds cnt00 ;
    by ngroup  result prime nsite ; 

data hds ;
  merge  hds cnttot ;
    by ngroup result prime ; 



proc sort ;
  by control ;
data hds ;
  merge hds (in=q1) isteer rsteer ;
    if q1 ; by control ;

/* create discrete variables for each treatment based on four 
possible outcomes:  both favored, white favored, minority 
favored, and neither favored.  Record neither favored if
we cannot distinguish between both or neither. */

rsteer11=0 ; rsteer10=0 ; rsteer01=0 ; rsteerc=1 ;
if whtrec=0 then rsteer11=1 ;
  else if whtrec=1 then rsteer10=1 ;
  else if whtrec=-1 then rsteer01=1 ;

isteer11=0 ; isteer10=0 ; isteer01=0 ; isteerc=1 ;
if whtnspct=0 then isteer11=1 ;
  else if whtnspct=1 then isteer10=1 ;
  else if whtnspct=-1 then isteer01=1 ;

avail11=0 ; avail10=0 ; avail01=0 ; availc=1 ;
if wavailad=1 and mavailad=1 then avail11=1 ;
  else if wavailad=1 and mavailad=0 then avail10=1 ;
  else if wavailad=0 and mavailad=1 then avail01=1 ;

avlsm11=0 ; avlsm10=0 ; avlsm01=0 ; avlsmc=1 ;
if wavailsm=1 and mavailsm=1 then avlsm11=1 ;
  else if wavailsm=1 and mavailsm=0 then avlsm10=1 ;
  else if wavailsm=0 and mavailsm=1 then avlsm01=1 ;

recom11=0 ; recom10=0 ; recom01=0 ; recomc=1 ;
if wrecomi=1 and mrecomi=1 then recom11=1 ;
  else if wrecomi=1 and mrecomi=0 then recom10=1 ;
  else if wrecomi=0 and mrecomi=1 then recom01=1 ;

  /* hierarchical composite for access */

waccess=0 ; maccess=0 ; 
if avail10=1 then waccess=1 ;
  else if avail01=1 then maccess=1 ;
  else if avlsm10=1 then waccess=1 ;
  else if avlsm01=1 then maccess=1 ;
  else if recom10=1 then waccess=1 ;
  else if recom01=1 then maccess=1 ;


  /* consistency composite for access */


wacccns=0 ; macccns=0 ; 
if (avail10=1 or avlsm10=1 or recom10=1) then wacccns=1 ;
if (avail01=1 or avlsm01=1 or recom01=1) then macccns=1 ;


  
inspad11=0 ; inspad10=0 ; inspad01=0 ; inspadc=1 ;
if winspadv=1 and minspadv=1 then inspad11=1 ;
  else if winspadv=1 and minspadv=0 then inspad10=1 ;
  else if winspadv=0 and minspadv=1 then inspad01=1 ;

inspsm11=0 ; inspsm10=0 ; inspsm01=0 ; inspsmc=1 ;
if winspsim=1 and minspsim=1 then inspsm11=1 ;
  else if winspsim=1 and minspsim=0 then inspsm10=1 ;
  else if winspsim=0 and minspsim=1 then inspsm01=1 ;

inspct11=0 ; inspct10=0 ; inspct01=0 ; inspctc=1 ;
if winspcti=1 and minspcti=1 then inspct11=1 ;
  else if winspcti=1 and minspcti=0 then inspct10=1 ;
  else if winspcti=0 and minspcti=1 then inspct01=1 ;

  /* hierarchical composite for inspection */

waccss2=0 ; maccss2=0 ;
if inspad10=1 then waccss2=1 ;
else if inspad01=1 then maccss2=1 ;
else if inspsm10=1 then waccss2=1 ;
else if inspsm01=1 then maccss2=1 ;
else if inspct10=1 then waccss2=1 ;
else if inspct01=1 then maccss2=1 ;

  /* consistency composite for inspection */

wacc2cns=0 ; macc2cns=0 ;
if (inspad10=1 or inspsm10=1 or inspct10=1) then wacc2cns=1 ;
if (inspad01=1 or inspsm01=1 or inspct01=1) then macc2cns=1 ;


nofutc11=0 ; nofutc10=0 ; nofutc01=0 ; nofutcc=1 ;
if wnofutcn=1 and mnofutcn=1 then nofutc11=1 ;
  else if wnofutcn=1 and mnofutcn=0 then nofutc01=1 ;
  else if wnofutcn=0 and mnofutcn=1 then nofutc10=1 ;

reqprq11=0 ; reqprq10=0 ; reqprq01=0 ; reqprqc=1 ; 
if wreqpreq=0 and mreqpreq=0 then reqprq11=1 ;
  else if wreqpreq=0 and mreqpreq=1 then reqprq10=1 ;
  else if wreqpreq=1 and mreqpreq=0 then reqprq01=1 ;

follow11=0 ; follow10=0 ; follow01=0 ; followc=1 ;
if wfollow=1 and mfollow=1 then follow11=1 ;
  else if wfollow=1 and mfollow=0 then follow10=1 ;
  else if wfollow=0 and mfollow=1 then follow01=1 ;

qual11=0 ; qual10=0 ; qual01=0 ; qualc=1 ;
if wqual=1 and mqual=1 then qual11=1 ;
  else if wqual=1 and mqual=0 then qual10=1 ;
  else if wqual=0 and mqual=1 then qual01=1 ;


  /* hierarchical composite for service  */

mservice=0 ; wservice=0 ;
if follow10=1 then wservice=1 ;
  else if follow01=1 then mservice=1 ;
  else if reqprq10=1 then wservice=1 ;
  else if reqprq01=1 then mservice=1 ;
  else if qual10=1 then wservice=1 ;
  else if qual01=1 then mservice=1 ;
  else if nofutc10=1 then wservice=1 ;
  else if nofutc01=1 then mservice=1 ;


  /* consistency composite for service  */


mservcns=0 ; wservcns=0 ;
if (follow10=1 or nofutc10=1 or qual10=1 or reqprq10=1)
   then wservcns=1 ;
if (follow01=1 or nofutc01=1 or qual01=1 or reqprq01=1)
   then mservcns=1 ;

prqual11=0 ; prqual10=0 ; prqual01=0 ; prqualc=1 ;
if wprequal=1 and mprequal=1 then prqual11=1 ;
  else if wprequal=1 and mprequal=0 then prqual10=1 ;
  else if wprequal=0 and mprequal=1 then prqual01=1 ;

finhlp11=0 ; finhlp10=0 ; finhlp01=0 ; finhlpc=1 ;
if wfinhelp=1 and mfinhelp=1 then finhlp11=1 ;
if wfinhelp=1 and mfinhelp=0 then finhlp10=1 ;
if wfinhelp=0 and mfinhelp=1 then finhlp01=1 ;

lndr11=0 ; lndr10=0 ; lndr01=0 ; lndrc=1 ;
if wlenders=1 and mlenders=1 then lndr11=1 ;
if wlenders=1 and mlenders=0 then lndr10=1 ;
if wlenders=0 and mlenders=1 then lndr01=1 ;

/* heirarchical composite for financing assistence */

wfnce=0 ; mfnce=0 ;
if finhlp10=1 then wfnce=1 ;
else if finhlp01=1 then mfnce=1 ;
else if prqual10=1 then wfnce=1 ;
else if prqual01=1 then mfnce=1 ;
else if lndr10=1 then wfnce=1 ;
else if lndr01=1 then mfnce=1 ;


/* consistency composite for financing assistence */

wfincns=0 ; mfincns=0 ;
if (finhlp10=1 or lndr10=1 or prqual10=1) then wfincns=1 ; 
if (finhlp01=1 or lndr01=1 or prqual01=1) then mfincns=1 ; 

access11=0 ; access10=0 ; access01=0 ; accessc=1 ;
if waccess=1 and maccess=1 then access11=1 ;
if waccess=1 and maccess=0 then access10=1 ;
if waccess=0 and maccess=1 then access01=1 ;

accss211=0 ; accss210=0 ; accss201=0 ; accss2c=1 ;
if waccss2=1 and maccss2=1 then accss211=1 ;
if waccss2=1 and maccss2=0 then accss210=1 ;
if waccss2=0 and maccss2=1 then accss201=1 ;

servic11=0 ; servic10=0 ; servic01=0 ; servicc=1 ;
if wservice=1 and mservice=1 then servic11=1 ;
if wservice=1 and mservice=0 then servic10=1 ;
if wservice=0 and mservice=1 then servic01=1 ;

fnce11=0 ; fnce10=0 ; fnce01=0 ; fncec=1 ;
if wfnce=1 and mfnce=1 then fnce11=1 ;
if wfnce=1 and mfnce=0 then fnce10=1 ;
if wfnce=0 and mfnce=1 then fnce01=1 ;

acccns11=0 ; acccns10=0 ; acccns01=0 ; acccnsc=1 ;
if wacccns=1 and macccns=1 then acccns11=1 ;
if wacccns=1 and macccns=0 then acccns10=1 ;
if wacccns=0 and macccns=1 then acccns01=1 ;

ac2cns11=0 ; ac2cns10=0 ; ac2cns01=0 ; ac2cnsc=1 ;
if wacc2cns=1 and macc2cns=1 then ac2cns11=1 ;
if wacc2cns=1 and macc2cns=0 then ac2cns10=1 ;
if wacc2cns=0 and macc2cns=1 then ac2cns01=1 ;

srvcns11=0 ; srvcns10=0 ; srvcns01=0 ; srvcnsc=1 ;
if wservcns=1 and mservcns=1 then srvcns11=1 ;
if wservcns=1 and mservcns=0 then srvcns10=1 ;
if wservcns=0 and mservcns=1 then srvcns01=1 ;

fincns11=0 ; fincns10=0 ; fincns01=0 ; fincnsc=1 ;
if wfincns=1 and mfincns=1 then fincns11=1 ; 
if wfincns=1 and mfincns=0 then fincns10=1 ; 
if wfincns=0 and mfincns=1 then fincns01=1 ; 

/* overall consistency composite */

cnsty11=0 ; cnsty10=0 ; cnsty01=0 ; cnstyc=1 ;
if (wfincns=1 or wservcns=1 or wacccns=1 or wacc2cns=1) and
   (mfincns=1 or mservcns=1 or macccns=1 or macc2cns=1)
      then cnsty11=1 ; 
else if (wfincns=1 or wservcns=1 or wacccns=1 or wacc2cns=1
     or rsteer10=1 or isteer10=1) and mfincns=0 and
     mservcns=0 and macccns=0 and macc2cns=0 and 
     rsteer01=0 and isteer01=0 then cnsty10=1 ;
else if (mfincns=1 or mservcns=1 or macccns=1 or macc2cns=1
     or rsteer01=1 or isteer01=1)  and wfincns=0 and
     wservcns=0 and wacccns=0 and wacc2cns=0 and 
      rsteer10=0 and isteer10=0 then cnsty01=1 ;



/* variable by variable construction of composite indicator */

heir11=0 ; heir10=0 ; heir01=0 ; heirc=1 ;
if avail10=1 then do ; 
  heir10=1 ;
  end ;
  else if avail01=1 then do ; 
  heir01=1 ;
  end ;
  else if inspad10=1 then do ;
  heir10=1 ;
  end ;
  else if inspad01=1 then do ;
  heir01=1 ;
  end ;
  else if avlsm10=1 then  do ;
  heir10=1 ;
  end ;
  else if avlsm01=1 then  do ;
  heir01=1 ;
  end ;
  else if inspsm10=1 then do ;
  heir10=1 ;
  end ;
  else if inspsm01=1 then do ;
  heir01=1 ;
  end ;
  else if rsteer10=1 then do ;
  heir10=1 ;
  end ; 
  else if rsteer01=1 then do ;
  heir01=1 ;
  end ; 
  else if recom10=1 then  do ;
  heir10=1 ;
  end ;
  else if recom01=1 then  do ;
  heir01=1 ;
  end ;
  else if isteer10=1 then do ;
  heir10=1 ;
  end ; 
  else if isteer01=1 then do ;
  heir01=1 ;
  end ; 
  else if inspct10=1 then do ;
  heir10=1 ;
  end ;
  else if inspct01=1 then do ;
  heir01=1 ;
  end ;
  else if finhlp10=1 then do ;
  heir10=1 ;
  end ;
  else if finhlp01=1 then do ;
  heir01=1 ;
  end ;
  else if prqual10=1 then do ;
  heir10=1 ;
  end ;
  else if prqual01=1 then do ;
  heir01=1 ;
  end ;
  else if lndr10=1 then do ;
  heir10=1 ;
  end ;
  else if lndr01=1 then do ;
  heir01=1 ;
  end ;
  else if follow10=1 then do ;
  heir10=1 ;
  end ;
  else if follow01=1 then do ;
  heir01=1 ;
  end ;
  else if reqprq10=1 then do ;
  heir10=1 ;
  end ;
  else if reqprq01=1 then do ;
  heir01=1 ;
  end ;
  else if qual10=1 then do ;
  heir10=1 ;
  end ;
  else if qual01=1 then do ;
  heir01=1 ;
  end ;
  else if nofutc10=1 then  do ;
  heir10=1 ;
  end ;
  else if nofutc01=1 then  do ;
  heir01=1 ;
  end ;
  else heir11=1 ;


davail=wavailad-mavailad ;

davlsm=wavailsm-mavailsm ;

drecom=wrecomi-mrecomi ;

daccess=waccess-maccess ;

dacccns=wacccns-macccns ;

dinspad=winspadv-minspadv ;

dinspsm=winspsim-minspsim ;

dinspct=winspcti-minspcti ;

daccss2=waccss2-maccss2 ;

dacc2cns=wacc2cns-macc2cns ;

drsteer=rsteer10-rsteer01 ;

disteer=isteer10-isteer01 ;

dfinhlp=finhlp10-finhlp01 ;

dprqual=prqual10-prqual01 ;

dlndr=lndr10-lndr01 ;

dfnce=wfnce-mfnce ;

dfincns=wfincns-mfincns ;

dfollow=wfollow-mfollow ;

dreqprq=reqprq10-reqprq01 ;

dqual=qual10-qual01 ;

dnofutc=wnofutcn-mnofutcn ;

dservic=wservice-mservice ;

dservcns=wservcns-mservcns ;

dheir=heir10-heir01 ;

dcnsty=cnsty10-cnsty01 ;

  if prime=1 then output hds ;
     else delete ;


proc sort ;
    by ngroup nsite count ; 

/* conduct sign test for every type of test and metro area */

proc univariate  ;
  var davail davlsm drecom daccess dacccns
      dinspad dinspsm  dinspct daccss2 dacc2cns
      drsteer disteer
      dfinhlp dprqual dlndr dfnce dfincns 
      dfollow dreqprq dqual dnofutc dservic dservcns
      dheir dcnsty ;
    by ngroup nsite count ; 







run;















run;










