****************************************************************            
* Program name:  sales_visit_p2.sas                                            
* Project:       Housing Discrimination Study Phase II                       
*                                                                           
*  Final version: Nov 11, 2002 by Steve Ross                            
*                                                                           
*  This program generates a clean sample of first and second                
*  sales site visits for all testers.  The site visits for both the         
*  majority and minority testers are merged with the sample of              
*  paired assignments.  A final sample of completed sales tests 
*  is created where each tester made at least one visit to the r
*  eal estate agency.                                     
*                                                                           
* Input Files:   sales.ssd01, assignp2.ssd01
*                                                                           
* Output Files:  salesp2.ssd01                                             
*                                                                           
*                                                                           
****************************************************************;           

options nocenter ;
/* ref lib */
libname hds2000 '/work/ross' ;

/* ref files */
filename sales '/work/ross/sales.ssd01' ;
filename assignp2 '/work/ross/assignp2.ssd01' ;

/* new file: salesp2.sas to salesp2.ssd01 */
filename salesp2 '/work/ross/salesp2.ssd01' ;

data sales ; set hds2000.sales ;

  count=1 ;

  if raceid<20 then race=raceid-10 ;
    else if raceid>30 then race=raceid-30 ;
    else race=raceid -20 ;

  if ssndvis=-1 or ssndvis=. then ssndvis=0 ;
  ssndvis=ssndvis+1 ;

  if race=1 then white=1 ;
    else white=0 ;

  if raceid>30 then delete ;
    else if race=-9 or race=7 then delete ;
    else output sales ;

/* separating dataset by 1st and 2nd visits */                                        
data sales_a ; set sales ;

  if ssndvis=1 then output sales_a ;
  else delete ;

proc sort ; by control white ;

data sales_b ; set sales ;

  if ssndvis=2 then output sales_b ;
  else delete ;

proc sort ; by control white ;


/* keeping only sales variables */

data assign ; set hds2000.assignp2 ;
  if ntype='S' then output assign ;
  else delete ;

proc sort ; by control ;


data wsvrfa ;
  set sales_a ;

  wtestida=testerid ;  
  wavladva=savlbad ;
  wsmbeda=ssamebed ;
  wminbeda=sminbed ;
  wtunita=stotunit ;
  warngm1a=sarngm1 ;
  warngm2a=sarngm2 ;
  warngm3a=sarngm3 ;
  warngm4a=sarngm4 ;

  waskbnka=spreq ;
  wtelbnka=srefpq ; /* please check */
  wagquala=sagqual ;
  wagfinda=sagfindf ;
  waglndra=saglndr ;
  wrfixeda=srfixed ;
  wradjsta=srarm ;
  wrfhavaa=srfhava ;
  wpquala=sprequal ;
  wqmarrya=sqmarry ;
  wqfamsza=sqfamsiz ;
  wqinca=sqincome ;
  wqoccupa=sqoccup ;
  wqempla=sqemplng ;
  wqasseta=sqasset ;
  wqdebtsa=sqdebts ;
  wqcreda=sqcredit ;
  wqdownpa=sqasset ;
  wsugprca=ssugpric ;
  wprclowa=spriclow ;
  wprichia=sprichi ;
  wsugmrta=ssugmort ;
  wmrtlowa=smortlow ;
  wmorthia=smorthi ;
  wsugrtea=ssugrate ;
  wrtelowa=sratelow ;
  wratehia=sratehi ;
  wsugdwna=ssugdown ;
  wdwnlwaa=sdwnlowa ;
  wdwnhiaa=sdwnhia ;
  wdwnlopa=sdwnlowp ;
  wdwnhipa=sdwnhip ;
  wsugpaya=ssugpay ;
  wpaylowa=spaylow ;
  wpayhia=spayhi ;
  wagpydna=sagpydn ;
  wagdbcna=sagdbcn ;
  wagcosna=sagcosn ;
  wagselaa=sagsela ;
  wagprqua=sagprqu ;
  wagnodsa=sagnods ;

  wagmet1a=sagmetp1 ; 
/* instead of 2 vars new dataset has 5 vars asking primary person to discuss 
   housing options */
  wagmet2a=sagmetp2 ;
  wagmet3a=sagmetp3 ;
  wagmet4a=sagmetp4 ;
  wagmet5a=sagmetp5 ;

  wagnam1a=sagname1 ;
  wagnam2a=sagname2 ;
  wagnam3a=sagname3 ;
  wagnam4a=sagname4 ;
  wagnam5a=sagname5 ;

/* 
date month and year is collapsed in one var, therefore temporarily 
commented out :
  vdated1a=sdate_d ;
  vdatem1a=sdate_m ;
  vdatey1a=sdate_y ;
*/
  wappdta=sapptd ;

  wappt_ha=sappth ;
  wappt_ma=sapptm ;
  wapptama=sapptam ;
  
  if white=1 then output wsvrfa ;
  else delete ;
  keep control wtestida wavladva wsmbeda wminbeda wtunita 
  warngm1a warngm2a warngm3a warngm4a waskbnka wtelbnka 
  wagquala wagfinda waglndra wrfixeda wradjsta wrfhavaa wpquala 
  wqmarrya wqfamsza wqinca wqoccupa wqempla wqasseta wqdebtsa 
  wqcreda wqdownpa wsugprca wprclowa wprichia wsugmrta 
  wmrtlowa wmorthia wsugrtea wrtelowa wratehia wsugdwna 
  wdwnlwaa wdwnhiaa wdwnlopa wdwnhipa wsugpaya wpaylowa 
  wpayhia wagpydna wagdbcna wagcosna wagselaa wagprqua 
  wagnodsa wagnam1a wagnam2a wagnam3a wagnam4a wagnam5a  
  wappdta wappt_ha wappt_ma wapptama wagmet1a wagmet2a wagmet3a 
  wagmet4a wagmet5a ;


proc sort ;
  by control ;

/* 1b */
data wsvrfb ;
  set sales_b ;

  wtestidb=testerid ;  
  wavladvb=savlbad ;
  wsmbedb=ssamebed ;
  wminbedb=sminbed ;
  wtunitb=stotunit ;
  warngm1b=sarngm1 ;
  warngm2b=sarngm2 ;
  warngm3b=sarngm3 ;
  warngm4b=sarngm4 ;

  waskbnkb=spreq ;
  wtelbnkb=srefpq ; /* please check */
  wagqualb=sagqual ;
  wagfindb=sagfindf ;
  waglndrb=saglndr ;
  wrfixedb=srfixed ;
  wradjstb=srarm ;
  wrfhavab=srfhava ;
  wpqualb=sprequal ;
  wqmarryb=sqmarry ;
  wqfamszb=sqfamsiz ;
  wqincb=sqincome ;
  wqoccupb=sqoccup ;
  wqemplb=sqemplng ;
  wqassetb=sqasset ;
  wqdebtsb=sqdebts ;
  wqcredb=sqcredit ;
  wqdownpb=sqasset ;
  wsugprcb=ssugpric ;
  wprclowb=spriclow ;
  wprichib=sprichi ;
  wsugmrtb=ssugmort ;
  wmrtlowb=smortlow ;
  wmorthib=smorthi ;
  wsugrteb=ssugrate ;
  wrtelowb=sratelow ;
  wratehib=sratehi ;
  wsugdwnb=ssugdown ;
  wdwnlwab=sdwnlowa ;
  wdwnhiab=sdwnhia ;
  wdwnlopb=sdwnlowp ;
  wdwnhipb=sdwnhip ;
  wsugpayb=ssugpay ;
  wpaylowb=spaylow ;
  wpayhib=spayhi ;
  wagpydnb=sagpydn ;
  wagdbcnb=sagdbcn ;
  wagcosnb=sagcosn ;
  wagselab=sagsela ;
  wagprqub=sagprqu ;
  wagnodsb=sagnods ;

  wagmet1b=sagmetp1 ; 
/* instead of 2 vars new dataset has 5 vars asking primary person to discuss 
   housing options */
  wagmet2b=sagmetp2 ;
  wagmet3b=sagmetp3 ;
  wagmet4b=sagmetp4 ;
  wagmet5b=sagmetp5 ;

  wagnam1b=sagname1 ;
  wagnam2b=sagname2 ;
  wagnam3b=sagname3 ;
  wagnam4b=sagname4 ;
  wagnam5b=sagname5 ;


/* 
date month and year is collapsed in one var, therefore temporarily 
commented out :
  wvdatedb=sdate_d ;
  wvdatemb=sdate_m ;
  wvdateyb=sdate_y ;
*/
  wappdtb=sapptd ;

  wappt_hb=sappth ;
  wappt_mb=sapptm ;
  wapptamb=sapptam ;

  if white=1 then output wsvrfb ;
  else delete ;
  keep control wtestidb wavladvb wsmbedb wminbedb wtunitb 
  warngm1b warngm2b warngm3b warngm4b waskbnkb wtelbnkb 
  wagqualb wagfindb waglndrb wrfixedb wradjstb wrfhavab wpqualb 
  wqmarryb wqfamszb wqincb wqoccupb wqemplb wqassetb wqdebtsb 
  wqcredb wqdownpb wsugprcb wprclowb wprichib wsugmrtb 
  wmrtlowb wmorthib wsugrteb wrtelowb wratehib wsugdwnb 
  wdwnlwab wdwnhiab wdwnlopb wdwnhipb wsugpayb wpaylowb 
  wpayhib wagpydnb wagdbcnb wagcosnb wagselab wagprqub 
  wagnodsb wagnam1b wagnam2b wagnam3b wagnam4b wagnam5b  
  wappdtb wappt_hb wappt_mb wapptamb wagmet1b wagmet2b wagmet3b 
  wagmet4b wagmet5b ;

proc sort ;
  by control ;

/* 2a */
data msvrfa ;
  set sales_a ;

  mtestida=testerid ;  
  mavladva=savlbad ;
  msmbeda=ssamebed ;
  mminbeda=sminbed ;
  mtunita=stotunit ;
  marngm1a=sarngm1 ;
  marngm2a=sarngm2 ;
  marngm3a=sarngm3 ;
  marngm4a=sarngm4 ;

  maskbnka=spreq ;
  mtelbnka=srefpq ; /* please check */
  magquala=sagqual ;
  magfinda=sagfindf ;
  maglndra=saglndr ;
  mrfixeda=srfixed ;
  mradjsta=srarm ;
  mrfhavaa=srfhava ;
  mpquala=sprequal ;
  mqmarrya=sqmarry ;
  mqfamsza=sqfamsiz ;
  mqinca=sqincome ;
  mqoccupa=sqoccup ;
  mqempla=sqemplng ;
  mqasseta=sqasset ;
  mqdebtsa=sqdebts ;
  mqcreda=sqcredit ;
  mqdownpa=sqasset ;
  msugprca=ssugpric ;
  mprclowa=spriclow ;
  mprichia=sprichi ;
  msugmrta=ssugmort ;
  mmrtlowa=smortlow ;
  mmorthia=smorthi ;
  msugrtea=ssugrate ;
  mrtelowa=sratelow ;
  mratehia=sratehi ;
  msugdwna=ssugdown ;
  mdwnlwaa=sdwnlowa ;
  mdwnhiaa=sdwnhia ;
  mdwnlopa=sdwnlowp ;
  mdwnhipa=sdwnhip ;
  msugpaya=ssugpay ;
  mpaylowa=spaylow ;
  mpayhia=spayhi ;
  magpydna=sagpydn ;
  magdbcna=sagdbcn ;
  magcosna=sagcosn ;
  magselaa=sagsela ;
  magprqua=sagprqu ;
  magnodsa=sagnods ;

  magmet1a=sagmetp1 ; 
/* instead of 2 vars new dataset has 5 vars asking primary person to discuss 
   housing options */
  magmet2a=sagmetp2 ;
  magmet3a=sagmetp3 ;
  magmet4a=sagmetp4 ;
  magmet5a=sagmetp5 ;

  magnam1a=sagname1 ;
  magnam2a=sagname2 ;
  magnam3a=sagname3 ;
  magnam4a=sagname4 ;
  magnam5a=sagname5 ;


/* 
date month and year is collapsed in one var, therefore temporarily 
commented out :
  mvdateda=sdate_d ;
  mvdatema=sdate_m ;
  mvdateya=sdate_y ;
*/
  mappdta=sapptd ;

  mappt_ha=sappth ;
  mappt_ma=sapptm ;
  mapptama=sapptam ;

  if white=0 then output msvrfa ;
  else delete ;
  keep control mtestida mavladva msmbeda mminbeda mtunita 
  marngm1a marngm2a marngm3a marngm4a maskbnka mtelbnka 
  magquala magfinda maglndra mrfixeda mradjsta mrfhavaa mpquala 
  mqmarrya mqfamsza mqinca mqoccupa mqempla mqasseta mqdebtsa 
  mqcreda mqdownpa msugprca mprclowa mprichia msugmrta 
  mmrtlowa mmorthia msugrtea mrtelowa mratehia msugdwna 
  mdwnlwaa mdwnhiaa mdwnlopa mdwnhipa msugpaya mpaylowa 
  mpayhia magpydna magdbcna magcosna magselaa magprqua 
  magnodsa magnam1a magnam2a magnam3a 
  magnam4a magnam5a mappdta mappt_ha 
  mappt_ma mapptama magmet1a magmet2a magmet3a magmet4a magmet5a ;

proc sort ;
  by control ;

/* 2b */
data msvrfb ;
  set sales_b ;

  mtestidb=testerid ;  
  mavladvb=savlbad ;
  msmbedb=ssamebed ;
  mminbedb=sminbed ;
  mtunitb=stotunit ;
  marngm1b=sarngm1 ;
  marngm2b=sarngm2 ;
  marngm3b=sarngm3 ;
  marngm4b=sarngm4 ;

  maskbnkb=spreq ;
  mtelbnkb=srefpq ; /* please check */
  magqualb=sagqual ;
  magfindb=sagfindf ;
  maglndrb=saglndr ;
  mrfixedb=srfixed ;
  mradjstb=srarm ;
  mrfhavab=srfhava ;
  mpqualb=sprequal ;
  mqmarryb=sqmarry ;
  mqfamszb=sqfamsiz ;
  mqincb=sqincome ;
  mqoccupb=sqoccup ;
  mqemplb=sqemplng ;
  mqassetb=sqasset ;
  mqdebtsb=sqdebts ;
  mqcredb=sqcredit ;
  mqdownpb=sqasset ;
  msugprcb=ssugpric ;
  mprclowb=spriclow ;
  mprichib=sprichi ;
  msugmrtb=ssugmort ;
  mmrtlowb=smortlow ;
  mmorthib=smorthi ;
  msugrteb=ssugrate ;
  mrtelowb=sratelow ;
  mratehib=sratehi ;
  msugdwnb=ssugdown ;
  mdwnlwab=sdwnlowa ;
  mdwnhiab=sdwnhia ;
  mdwnlopb=sdwnlowp ;
  mdwnhipb=sdwnhip ;
  msugpayb=ssugpay ;
  mpaylowb=spaylow ;
  mpayhib=spayhi ;
  magpydnb=sagpydn ;
  magdbcnb=sagdbcn ;
  magcosnb=sagcosn ;
  magselab=sagsela ;
  magprqub=sagprqu ;
  magnodsb=sagnods ;

  magmet1b=sagmetp1 ; 
/* instead of 2 vars new dataset has 5 vars asking primary person to discuss 
   housing options */
  magmet2b=sagmetp2 ;
  magmet3b=sagmetp3 ;
  magmet4b=sagmetp4 ;
  magmet5b=sagmetp5 ;
 
  magnam1b=sagname1 ;
  magnam2b=sagname2 ;
  magnam3b=sagname3 ;
  magnam4b=sagname4 ;
  magnam5b=sagname5 ;


/* 
date month and year is collapsed in one var, therefore temporarily 
commented out :
  mvdatedb=sdate_d ;
  mvdatemb=sdate_m ;
  mvdateyb=sdate_y ;
*/
  mappdtb=sapptd ;

  mappt_hb=sappth ;
  mappt_mb=sapptm ;
  mapptamb=sapptam ;

  if white=0 then output msvrfb ;
  else delete ;
  keep control mtestidb mavladvb msmbedb mminbedb mtunitb 
  marngm1b marngm2b marngm3b marngm4b maskbnkb mtelbnkb 
  magqualb magfindb maglndrb mrfixedb mradjstb mrfhavab mpqualb 
  mqmarryb mqfamszb mqincb mqoccupb mqemplb mqassetb mqdebtsb 
  mqcredb mqdownpb msugprcb mprclowb mprichib msugmrtb 
  mmrtlowb mmorthib msugrteb mrtelowb mratehib msugdwnb 
  mdwnlwab mdwnhiab mdwnlopb mdwnhipb msugpayb mpaylowb 
  mpayhib magpydnb magdbcnb magcosnb magselab magprqub 
  magnodsb magnam1b magnam2b magnam3b 
  magnam4b magnam5b mappdtb mappt_hb 
  mappt_mb mapptamb magmet1b magmet2b magmet3b magmet4b magmet5b ;

proc sort ;
  by control ;
 
/* merge minority treatment information with sample of tests */

data assign ;
  merge assign (in=q1) wsvrfa (in=q2) wsvrfb (in=q3) msvrfa (in=q4) 
  msvrfb (in=q5) ;
  by control ;
  
  wsvrfa=q2 ;
  wsvrfb=q3 ;
  msvrfa=q4 ;
  msvrfb=q5 ;
 
  if q1 then output assign ;
  else delete ;

/* keep tests where a site visit was completed by both testers */

data hds2000.salesp2 problem ; set assign ;
  nsite=substr(control,1,2) ;
  if  (wsvrfa=1 or wsvrfb=1) and (msvrfa=1 or msvrfb=1) 
             then output hds2000.salesp2 ;
  else output problem ;

proc freq data=hds2000.salesp2 ;
  tables nsite*ngroup ;
run ;




